@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -140,30 +140,45 @@ function isMailAddress($str)
  *
  * ファイルポインタから行を取得し、解析したデータを配列で返す
  *
- * @param resource  $fp		ファイルポインタ
- * @return array			解析後のデータ
+ * @param resource  $fp				ファイルポインタ
+ * @param int		$delimType		区切りタイプ(0=カンマ、1=タブ)
+ * @return array					解析後のデータ
  */
-function fgetByCsv(&$fp)
+function fgetByCsv(&$fp, $delimType = 0)
 {
 	if (feof($fp)) return false;
 
-	$csv = '';
-	while (!feof($fp)){
-	    $csv .= mb_convert_encoding(fgets($fp), 'UTF-8', 'SJIS-win');
-	    if (((preg_match_all('/"/', $csv, $matches)) % 2) == 0) break;
-	}
+	if ($delimType == 0){
+		$csv = '';
+		while (!feof($fp)){
+		    $csv .= mb_convert_encoding(fgets($fp), 'UTF-8', 'SJIS-win');
+		    if (((preg_match_all('/"/', $csv, $matches)) % 2) == 0) break;
+		}
 
-	$values = array();
-	$temp = preg_replace('/(?:\x0D\x0A|[\x0D\x0A])?$/', ',', $csv, 1);
-	preg_match_all('/("[^"]*(?:""[^"]*)*"|[^,]*),/', $temp, $matches);
+		$values = array();
+		$temp = preg_replace('/(?:\x0D\x0A|[\x0D\x0A])?$/', ',', $csv, 1);
+		preg_match_all('/("[^"]*(?:""[^"]*)*"|[^,]*),/', $temp, $matches);
 
-	for ($i = 0; $i < count($matches[1]) ; $i++){
-	    if (preg_match('/^"(.*)"$/s', $matches[1][$i], $m)){
-	        $matches[1][$i] = preg_replace('/""/', '"', $m[1]);
-	    }
-	    $values[] = $matches[1][$i];
+		for ($i = 0; $i < count($matches[1]) ; $i++){
+		    if (preg_match('/^"(.*)"$/s', $matches[1][$i], $m)){
+		        $matches[1][$i] = preg_replace('/""/', '"', $m[1]);
+		    }
+		    $values[] = $matches[1][$i];
+		}
+		return $values;
+	} else if ($delimType == 1){
+		// UTF-8に変換
+		$csv = '';
+		while (!feof($fp)){		// 空行は読み飛ばす
+		    $csv = mb_convert_encoding(fgets($fp), 'UTF-8', 'SJIS-win');
+			$checkCsv = trim($csv);
+			if (!empty($checkCsv)) break;
+		}
+		if (feof($fp)) return false;
+	
+		$values = explode("\t", $csv);
+		return $values;
 	}
-	return $values;
 }
 /**
  * CSVファイルをタブで切り出し
@@ -232,4 +247,22 @@ function parseUserCustomParam($src)
 	}
 	return $dest;
 }
+/**
+ * URLパラメータを連想配列に変換
+ *
+ * フォーマット　key1=value1&key2=value2&key3=value3
+ *
+ * @param string $src			解析対象
+ * @return array $dest			解析後の連想配列
+ */
+function parseUrlParam($src)
+{
+	$dest = array();
+	$parsedArray = explode('&', $src);
+	for ($i = 0; $i < count($parsedArray); $i++){
+		list($key, $value) = explode('=', $parsedArray[$i]);
+		if (!empty($key)) $dest[$key] = $value;
+	}
+	return $dest;
+}
 ?>
