@@ -147,17 +147,7 @@ class BaseWidgetContainer
 	 */
 	function convertToDispString($src)
 	{
-	/*
-		$dest = $src;
-		
-		// タグ文字を回避
-		$dest = ereg_replace("&", "&amp;", $dest);
-		$dest = ereg_replace("<", "&lt;", $dest);
-		$dest = ereg_replace(">", "&gt;", $dest);
-		$dest = ereg_replace("\"", "&quot;", $dest);
-		return $dest;
-		*/
-		//return htmlentities($src, ENT_COMPAT, M3_ENCODING);
+		// 変換文字「&<>"」
 		return htmlentities($src, ENT_COMPAT, M3_HTML_CHARSET);
 	}
 	/**
