@@ -1609,12 +1609,15 @@ class SystemDb extends BaseDb
 	 * @param int $type				実行タイプ(0=ページからの実行、1=単体実行)
 	 * @param string $cmd			実行コマンド
 	 * @param string $message		メッセージ
-	 * @return bool					true=成功、false=失敗
+	 * @return bool					true=ログ出力完了、false=失敗
 	 */
 	function writeWidgetLog($widgetId, $type, $cmd = '', $message = '')
 	{
 		global $gEnvManager;
 		
+		// ログを残さないときは終了
+		if (!$gEnvManager->getWidgetLog()) return false;
+		
 		$logSerial = $gEnvManager->getCurrentAccessLogSerial();	// 現在のアクセスログシリアル番号
 		
 		// トランザクション開始
@@ -1631,16 +1634,20 @@ class SystemDb extends BaseDb
 	 * 初期導入パラメータを取得
 	 *
 	 * @param string	$key			キー
+	 * @param string	$name			名前
 	 * @return string					値、未設定の場合は空文字列
 	 */
-	function getInitParam($key)
+	function getKeyValue($key, &$name)
 	{
 		$retValue = '';
-		$queryStr  = 'SELECT * FROM _init_param ';
-		$queryStr .=   'WHERE ip_deleted = false ';	// 削除されていない
-		$queryStr .=   'AND ip_id = ? ';
+		$queryStr  = 'SELECT * FROM _key_value ';
+		$queryStr .=   'WHERE kv_deleted = false ';	// 削除されていない
+		$queryStr .=   'AND kv_id = ? ';
 		$ret = $this->selectRecord($queryStr, array($key), $row);
-		if ($ret) $retValue = $row['ip_value'];
+		if ($ret){
+			$retValue = $row['kv_value'];
+			$name = $row['kv_name'];
+		}
 		return $retValue;
 	}
 	/**
@@ -1648,9 +1655,10 @@ class SystemDb extends BaseDb
 	 *
 	 * @param string $key		キーとなる項目値
 	 * @param string $value		値
+	 * @param string $name		名前
 	 * @return					true = 正常、false=異常
 	 */
-	function updateInitParam($key, $value)
+	function updateKeyValue($key, $value, $name='')
 	{
 		global $gEnvManager;
 		
@@ -1662,26 +1670,26 @@ class SystemDb extends BaseDb
 		
 		// 前レコードの削除状態チェック
 		$historyIndex = 0;
-		$name = '';
+//		$name = '';
 		$desc = '';
-		$queryStr = 'SELECT * FROM _init_param ';
-		$queryStr .=  'WHERE ip_id = ? ';
-		$queryStr .=  'ORDER BY ip_history_index DESC ';
+		$queryStr = 'SELECT * FROM _key_value ';
+		$queryStr .=  'WHERE kv_id = ? ';
+		$queryStr .=  'ORDER BY kv_history_index DESC ';
 		$ret = $this->selectRecord($queryStr, array($key), $row);
 		if ($ret){
-			$historyIndex = $row['ip_history_index'] + 1;
-			$name = $row['ip_name'];
-			$desc = $row['ip_description'];
+			$historyIndex = $row['kv_history_index'] + 1;
+//			$name = $row['kv_name'];
+			$desc = $row['kv_description'];
 			
 			// レコードが削除されていない場合は削除
-			if (!$row['ip_deleted']){
+			if (!$row['kv_deleted']){
 				// 古いレコードを削除
-				$queryStr  = 'UPDATE _init_param ';
-				$queryStr .=   'SET ip_deleted = true, ';	// 削除
-				$queryStr .=     'ip_update_user_id = ?, ';
-				$queryStr .=     'ip_update_dt = ? ';
-				$queryStr .=   'WHERE ip_serial = ?';
-				$ret = $this->execStatement($queryStr, array($userId, $now, $row['ip_serial']));
+				$queryStr  = 'UPDATE _key_value ';
+				$queryStr .=   'SET kv_deleted = true, ';	// 削除
+				$queryStr .=     'kv_update_user_id = ?, ';
+				$queryStr .=     'kv_update_dt = ? ';
+				$queryStr .=   'WHERE kv_serial = ?';
+				$ret = $this->execStatement($queryStr, array($userId, $now, $row['kv_serial']));
 				if (!$ret){
 					$this->endTransaction();
 					return false;
@@ -1690,8 +1698,8 @@ class SystemDb extends BaseDb
 		}
 		
 		// データを追加
-		$queryStr = 'INSERT INTO _init_param ';
-		$queryStr .=  '(ip_id, ip_history_index, ip_value, ip_name, ip_description, ip_create_user_id, ip_create_dt) ';
+		$queryStr = 'INSERT INTO _key_value ';
+		$queryStr .=  '(kv_id, kv_history_index, kv_value, kv_name, kv_description, kv_create_user_id, kv_create_dt) ';
 		$queryStr .=  'VALUES ';
 		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?)';
 		$this->execStatement($queryStr, array($key, $historyIndex, $value, $name, $desc, $userId, $now));
