@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    Release 1.1.0 SVN: $Id$
+ * @version    Release 1.2.0 SVN: $Id$
  * @link       http://www.magic3.org
  */
 if (defined("M3_SYSTEM_DEFINE_INCLUDED")) return;
@@ -40,8 +40,8 @@ define('M3_SYSTEM_DEBUG_OUT', true);// デバッグ文出力を行うかどう
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'1.1.2');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2008/1/9');		// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'1.2.0');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2008/1/23');		// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms & web communication framework.');		// システムの説明
 
@@ -99,6 +99,7 @@ define('M3_DATE_INIT_VALUE_PGSQL',			'0001-01-01');			// Date型データの初
 define('M3_TB_FIELD_SYSTEM_NAME',		'system_name');				// システム名称
 define('M3_TB_FIELD_SYSTEM_VERSION',	'system_version');			// システムバージョン
 // HTMLヘッダに出力する項目
+define('M3_TB_FIELD_SITE_TITLE',		'head_title');				// サイトのタイトル
 define('M3_TB_FIELD_SITE_DESCRIPTION',	'head_description');		// サイトの説明
 define('M3_TB_FIELD_SITE_KEYWORDS',		'head_keywords');			// 検索エンジン用キーワード
 define('M3_TB_FIELD_SITE_ROBOTS',		'head_robots');				// 検索ロボットへの指示
@@ -184,6 +185,7 @@ require_once(dirname(__FILE__) . '/manager/analyzeManager.php');
 require_once(dirname(__FILE__) . '/manager/messageManager.php');
 require_once(dirname(__FILE__) . '/manager/initialManager.php');
 require_once(dirname(__FILE__) . '/manager/cmdParamManager.php');
+require_once(dirname(__FILE__) . '/manager/textConvManager.php');
 
 // マネージャーの作成、初期化
 $gLogManager 		= new LogManager();		// これよりロギング可能
@@ -205,6 +207,7 @@ $gAnalyzeManager	= new AnalyzeManager();
 $gMessageManager	= new MessageManager();
 $gInitialManager	= new InitialManager();
 $gCmdParamManager	= new CmdParamManager();
+$gTextConvManager	= new TextConvManager();
 
 // 追加クラスの読み込み
 $gInstanceManager->loadAddonClass();
