@@ -31,6 +31,7 @@ class EnvManager
 	private $currentWidgetPrefix;	// 現在作成中のウィジェットのプレフィックス文字列
 	private $defaultLanguage;	// デフォルト言語(システムで固定)
 	private $currentLanguage;	// 現在の言語(ユーザによって可変)
+	private $multiLanguage;		// 多言語対応かどうか
  	private $db;				// DBオブジェクト
 	private $canUseDbSession;	// DBセッションが使用できるかどうか
 	private $canUseDb;			// DBが使用可能状態にあるかどうか
@@ -39,8 +40,11 @@ class EnvManager
 	private $siteOwner;			// サイト所有者
 	private $siteCopyRight;		// サイトコピーライト
 	private $siteEmail;			// サイトEメール
+	private $widgetLog;			// ウィジェット実行ログを残すかどうか
 	const DEFAULT_CSV_DELIM_CODE = 'csv_delim_code';		// デフォルトのCSV区切り文字コード
 	const DEFAULT_CSV_NL_CODE = 'csv_nl_code';		// デフォルトのCSV改行コード
+	const DEFAULT_CSV_FILE_SUFFIX = 'csv_file_suffix';		// デフォルトのCSVファイル拡張子
+	const MULTI_LANGUAGE = 'multi_language';		// 多言語対応かどうか
 	
 	/**
 	 * コンストラクタ
@@ -97,7 +101,8 @@ class EnvManager
 		$this->currentLanguage = $this->defaultLanguage;
 		
 		// 言語変更可能かどうか
-		$this->canChangeLang = $this->db->getCanChangeLang();		
+		$this->canChangeLang = $this->db->getCanChangeLang();
+		$this->multiLanguage = $this->db->getSystemConfig(self::MULTI_LANGUAGE);;		// 多言語対応かどうか
 	}
 	/**
 	 * デバッグ出力を行うかどうか
@@ -841,7 +846,13 @@ class EnvManager
 	{
 		return $this->canChangeLang;
 	}
-
+	/**
+	 * 多言語対応かどうかを取得
+	 */
+	public function getMultiLanguage()
+	{
+		return $this->multiLanguage;
+	}
 	/**
 	 * DBセッションが使用できるかどうか
 	 */
@@ -953,5 +964,23 @@ class EnvManager
 	{
 		return $this->db->getSystemConfig(self::DEFAULT_CSV_NL_CODE);
 	}
+	/**
+	 * デフォルトCSVファイル拡張子を取得
+	 *
+	 * @return string		改行文字
+	 */
+	public function getDefaultCsvFileSuffix()
+	{
+		return $this->db->getSystemConfig(self::DEFAULT_CSV_FILE_SUFFIX);
+	}
+	/**
+	 * ウィジェット実行ログを残すかどうか
+	 *
+	 * @return bool		true=ログ出力、false=ログ出力しない
+	 */
+	public function getWidgetLog()
+	{
+		return $this->widgetLog;
+	}
 }
 ?>
