@@ -10,7 +10,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -786,7 +786,6 @@ class PageManager
 		if (!empty($this->popupMsg)){
 			echo '<script language="JavaScript">' . M3_NL . '<!--' . M3_NL .  'alert("' . $this->popupMsg . '");' . M3_NL . '// -->' . M3_NL . '</script>';
 		}
-		
 		// サイトの説明
 		$desc = htmlspecialchars(trim($this->db->getSiteDefValue(M3_TB_FIELD_SITE_DESCRIPTION)));
 		if (!empty($desc)){
@@ -821,6 +820,12 @@ class PageManager
 		// outputs link tag for page
 		echo '<link rel="shortcut icon" href="' . $icon .'" />' . M3_NL;
 		
+		// ######## 画面タイトル ##########
+		// 画面ごとにタイトルを変更する場合はここを修正
+		$title = htmlspecialchars(trim($this->db->getSiteDefValue(M3_TB_FIELD_SITE_TITLE)));
+		if (!empty($title)){
+			echo '<title>' . $title . '</title>' . M3_NL;
+		}
 		// JavaScriptグローバル変数の設定
 		echo '<script type="text/javascript">' . M3_NL;
 		echo '<!--' . M3_NL;
