@@ -16,14 +16,15 @@ CREATE TABLE _system_config (
 ) TYPE=innodb;
 INSERT INTO _system_config (sc_id,                         sc_value, sc_name,                sc_index) VALUES
 ('system_name',                 'Magic3',     'システム名称',                    0),
-('db_version',                  '2008010301', 'DBバージョン',                    1),
+('db_version',                  '2008011701', 'DBバージョン',                    1),
 ('server_id',                   '',           'サーバ識別用ID',                  2),
 ('default_lang',                'ja',         'デフォルト言語',                  3),
+('multi_language',               '0',          '多言語対応',                      4),
 ('csv_upload_encoding',         'SJIS-win',   'CSVアップロードエンコード',       5),
 ('csv_download_encoding',       'SJIS-win',   'CSVダウンロードエンコード',       6),
-('csv_delim_code',              '\t',         'CSV区切りコード',                 7),
+('csv_delim_code',              ',',          'CSV区切りコード',                 7),
 ('csv_nl_code',                 '\r\n',       'CSV改行コード',                   8),
-('csv_file_suffix',             '.txt',       'CSVファイル拡張子',               9),
+('csv_file_suffix',             '.csv',       'CSVファイル拡張子',               9),
 ('permit_init_system',          '0',          'システム初期化許可',              10),
 ('permit_change_lang',          '1',          '処理言語変更許可',                11),
 ('permit_detail_config',        '0',          'システム詳細設定許可',            12),
@@ -110,24 +111,24 @@ CREATE TABLE _version (
 INSERT INTO _version (vs_id,         vs_value,     vs_name)
 VALUES               ('basic_table', '2007122201', '基本テーブルのバージョン');
 
--- 初期導入パラメータマスター
-DROP TABLE IF EXISTS _init_param;
-CREATE TABLE _init_param (
-    ip_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
-    ip_id                VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ID(Key)
-    ip_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+-- 汎用キー値型パラメータマスター
+DROP TABLE IF EXISTS _key_value;
+CREATE TABLE _key_value (
+    kv_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    kv_id                VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ID(Key)
+    kv_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
     
-    ip_value             TEXT           DEFAULT ''                    NOT NULL,      -- 値
-    ip_name              VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- 名称
-    ip_description       VARCHAR(80)    DEFAULT ''                    NOT NULL,      -- 説明
+    kv_value             TEXT           DEFAULT ''                    NOT NULL,      -- 値
+    kv_name              VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- 名称
+    kv_description       VARCHAR(80)    DEFAULT ''                    NOT NULL,      -- 説明
     
-    ip_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
-    ip_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
-    ip_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
-    ip_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
-    ip_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
-    PRIMARY KEY          (ip_serial),
-    UNIQUE               (ip_id,        ip_history_index)
+    kv_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
+    kv_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
+    kv_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    kv_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    kv_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (kv_serial),
+    UNIQUE               (kv_id,        kv_history_index)
 ) TYPE=innodb;
 
 -- ウィジェットパラメータ更新マスター
@@ -135,7 +136,7 @@ DROP TABLE IF EXISTS _widget_param_update;
 CREATE TABLE _widget_param_update (
     wu_widget_id         VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- ウィジェットID(ファイル名)
     wu_member_name       VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- オブジェクトメンバー名
-    wu_init_param_id     VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- 対応する初期導入パラメータマスターのID
+    wu_key_value_id      VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- 対応する汎用キー値型パラメータマスターのID
     wu_group_id          VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 項目グループ識別ID
     PRIMARY KEY          (wu_widget_id, wu_member_name)
 ) TYPE=innodb;
@@ -582,7 +583,7 @@ CREATE TABLE _page_def_set (
 DROP TABLE IF EXISTS _site_def;
 CREATE TABLE _site_def (
     sd_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
-    sd_id                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 定義項目ID
+    sd_id                VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 定義項目ID
     sd_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
     sd_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
     sd_value             VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 値
@@ -596,13 +597,20 @@ CREATE TABLE _site_def (
     UNIQUE               (sd_id,        sd_language_id,               sd_history_index)
 ) TYPE=innodb;
 INSERT INTO `_site_def` (`sd_id`,              `sd_language_id`, `sd_value`,         `sd_create_dt`) VALUES
-('head_description', 'ja',           'no_description', now()),
-('head_keywords',    'ja',           'no_keyword',     now()),
-('head_robots',      'ja',           'index, follow',  now()),
-('site_name',        'ja',           'site name undefined',     now()),
-('site_owner',       'ja',           'site owner undefined',     now()),
-('site_copyright',  'ja',           'copyright undefined',     now()),
-('site_email',       'ja',           '',     now());
+('head_description', 'ja',           '', now()),
+('head_keywords',    'ja',           '',     now()),
+('head_robots',      'ja',           '',  now()),
+('head_title',      'ja',           '',  now()),
+('site_name',        'ja',           '',     now()),
+('site_owner',       'ja',           '',     now()),
+('site_copyright',  'ja',           '',     now()),
+('site_email',       'ja',           '',     now()),
+('license_key',  'ja',           '',     now()),
+('license_email',       'ja',           '',     now()),
+('license_name',  'ja',           '',     now()),
+('license_zipcode',  'ja',           '',     now()),
+('license_address',  'ja',           '',     now()),
+('license_fax',  'ja',           '',     now());
 
 -- メール送信ログトラン
 DROP TABLE IF EXISTS _mail_send_log;
