@@ -13,28 +13,36 @@ CREATE TABLE commerce_config (
     cg_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
     PRIMARY KEY          (cg_id)
 ) TYPE=innodb;
-INSERT INTO commerce_config (cg_id,                  cg_value, cg_name,                        cg_index)
-VALUES                      ('default_currency',     'JPY',    'デフォルト通貨',               0);
-INSERT INTO commerce_config (cg_id,                  cg_value, cg_name,                        cg_index)
-VALUES                      ('default_tax_type',     'sales',  'デフォルト課税タイプ',         1);
-INSERT INTO commerce_config (cg_id,                  cg_value, cg_name,                        cg_index)
-VALUES                      ('tax_in_price',         '0',      '税処理区分',                   2);      -- 0=外税、1=内税
-INSERT INTO commerce_config (cg_id,                  cg_value, cg_name,                        cg_index)
-VALUES                      ('price_calc_type',      '0',      '金額端数処理',                 3);      -- 0=切り捨て、1=切り上げ、2=四捨五入
-INSERT INTO commerce_config (cg_id,                  cg_value, cg_name,                        cg_index)
-VALUES                      ('use_email',            '0',      'メール送信機能',               4);
-INSERT INTO commerce_config (cg_id,                  cg_value, cg_name,                        cg_index)
-VALUES                      ('shop_email',           '',       'ショップ宛てメールアドレス',   5);
-INSERT INTO commerce_config (cg_id,                  cg_value, cg_name,                        cg_index)
-VALUES                      ('auto_email_sender',    '',       '自動送信メール送信元アドレス', 6);
-INSERT INTO commerce_config (cg_id,                  cg_value, cg_name,                        cg_index)
-VALUES                      ('shop_name',            '',       'ショップ名',                   7);
-INSERT INTO commerce_config (cg_id,                  cg_value, cg_name,                        cg_index)
-VALUES                      ('shop_owner',           '',       'ショップオーナー名',           8);
-INSERT INTO commerce_config (cg_id,                  cg_value, cg_name,                        cg_index)
-VALUES                      ('shop_address',         '',       'ショップ住所',                 9);
-INSERT INTO commerce_config (cg_id,                  cg_value, cg_name,                        cg_index)
-VALUES                      ('shop_phone',           '',       'ショップ電話番号',             10);
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('default_currency',       'JPY',    'デフォルト通貨',               0);
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('default_tax_type',       'sales',  'デフォルト課税タイプ',         1);
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('tax_in_price',           '0',      '税処理区分',                   2);      -- 0=外税、1=内税
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('price_calc_type',        '0',      '金額端数処理',                 3);      -- 0=切り捨て、1=切り上げ、2=四捨五入
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('tax_calc_type',          '0',      '税端数処理',                   4);      -- 0=切り捨て、1=切り上げ、2=四捨五入
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('use_email',              '1',      'メール送信機能',               5);
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('shop_email',             '',       'ショップ宛てメールアドレス',   6);
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('auto_email_sender',      '',       '自動送信メール送信元アドレス', 7);
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('shop_name',              '',       'ショップ名',                   8);
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('shop_owner',             '',       'ショップオーナー名',           9);
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('shop_address',           '',       'ショップ住所',                 10);
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('shop_phone',             '',       'ショップ電話番号',             11);
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('category_select_count',  '2',      '商品カテゴリー選択可能数',     12);
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('order_cancel_hour',      '24',     '注文のキャンセル可能時間',     13);
+INSERT INTO commerce_config (cg_id,                    cg_value, cg_name,                        cg_index)
+VALUES                      ('disp_product_count',     '10',     '商品一覧表示項目数',           14);
 
 -- 単位マスター
 DROP TABLE IF EXISTS unit_type;
@@ -83,6 +91,7 @@ CREATE TABLE tax_type (
     tt_id                VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 種別ID
     tt_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
     tt_tax_rate_type     INT            DEFAULT 0                     NOT NULL,      -- 税率種別(0=税率なし、1=固定(tax_rateテーブル))
+    tt_tax_inout         SMALLINT       DEFAULT 0                     NOT NULL,      -- 内税外税区分(0=外税、1=内税)
     tt_tax_rate_id       VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 税率ID
     tt_name              VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 名称
     tt_description       VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 説明
@@ -90,8 +99,8 @@ CREATE TABLE tax_type (
     tt_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
     PRIMARY KEY          (tt_id,        tt_language_id)
 ) TYPE=innodb;
-INSERT INTO tax_type (tt_id, tt_language_id, tt_tax_rate_type, tt_tax_rate_id, tt_name, tt_geo_zone_id, tt_index) VALUES ('notax', 'ja', 0, '',           '課税なし', '1', 0);
-INSERT INTO tax_type (tt_id, tt_language_id, tt_tax_rate_type, tt_tax_rate_id, tt_name, tt_geo_zone_id, tt_index) VALUES ('sales', 'ja', 1, 'rate_sales', '消費税',   '1', 1);
+INSERT INTO tax_type (tt_id, tt_language_id, tt_tax_rate_type, tt_tax_rate_id, tt_name, tt_geo_zone_id, tt_index) VALUES ('sales', 'ja', 1, 'rate_sales', '課税(外税)',   '1', 0);
+INSERT INTO tax_type (tt_id, tt_language_id, tt_tax_rate_type, tt_tax_rate_id, tt_name, tt_geo_zone_id, tt_index) VALUES ('notax', 'ja', 0, '',           '非課税', '1', 1);
 
 -- 地理的地域マスター
 DROP TABLE IF EXISTS geo_zone;
@@ -221,6 +230,20 @@ CREATE TABLE product_category (
     UNIQUE               (pc_id,        pc_language_id,               pc_history_index)
 ) TYPE=innodb;
 
+-- 商品と商品カテゴリーの対応付けマスター
+DROP TABLE IF EXISTS product_with_category;
+CREATE TABLE product_with_category (
+    pw_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    pw_product_id        INT            DEFAULT 0                     NOT NULL,      -- 商品ID
+    pw_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    pw_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+    pw_index             INT            DEFAULT 0                     NOT NULL,      -- インデックス番号
+    pw_category_id       INT            DEFAULT 0                     NOT NULL,      -- 商品カテゴリーID
+    pw_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (pw_serial),
+    UNIQUE               (pw_product_id,        pw_language_id,       pw_history_index,     pw_index)
+) TYPE=innodb;
+
 -- 価格種別マスター
 DROP TABLE IF EXISTS price_type;
 CREATE TABLE price_type (
@@ -261,21 +284,6 @@ INSERT INTO order_status (os_id, os_language_id, os_name) VALUES (402, 'ja', '
 INSERT INTO order_status (os_id, os_language_id, os_name) VALUES (500, 'ja', '終了');
 INSERT INTO order_status (os_id, os_language_id, os_name) VALUES (501, 'ja', 'キャンセル');
 
--- 支払い方法カテゴリーマスター
-DROP TABLE IF EXISTS pay_method;
-CREATE TABLE pay_method (
-    pm_id                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 支払い方法ID
-    pm_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
-    pm_name              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- 支払い方法名
-    pm_sort_order        INT            DEFAULT 0                     NOT NULL,      -- ソート用
-    PRIMARY KEY          (pm_id,        pm_language_id)
-) TYPE=innodb;
-INSERT INTO pay_method VALUES ('furikae',  'ja', '郵便振替', 0);
-INSERT INTO pay_method VALUES ('kakidome', 'ja', '現金書留', 1);
-INSERT INTO pay_method VALUES ('furikomi', 'ja', '銀行振込', 2);
-INSERT INTO pay_method VALUES ('daibiki',  'ja', '代金引換', 3);
-INSERT INTO pay_method VALUES ('card',     'ja', 'クレジットカード', 4);
-
 -- 支払い方法マスター
 DROP TABLE IF EXISTS pay_method_def;
 CREATE TABLE pay_method_def (
@@ -306,18 +314,6 @@ INSERT INTO pay_method_def (po_id, po_language_id, po_name, po_index) VALUES ('f
 INSERT INTO pay_method_def (po_id, po_language_id, po_name, po_index) VALUES ('daibiki',  'ja', '代金引換', 4);
 INSERT INTO pay_method_def (po_id, po_language_id, po_name, po_index) VALUES ('card',     'ja', 'クレジットカード', 5);
 
--- 配送方法カテゴリーマスター
-DROP TABLE IF EXISTS delivery_method;
-CREATE TABLE delivery_method (
-    dm_id                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 配送方法ID
-    dm_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
-    dm_name              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- 配送方法名
-    dm_sort_order        INT            DEFAULT 0                     NOT NULL,      -- ソート用
-    PRIMARY KEY          (dm_id,        dm_language_id)
-) TYPE=innodb;
-INSERT INTO delivery_method VALUES ('yubin',    'ja', '一般小包郵便物', 0);
-INSERT INTO delivery_method VALUES ('takuhai',  'ja', '宅配',           1);
-
 -- 配送方法マスター
 DROP TABLE IF EXISTS delivery_method_def;
 CREATE TABLE delivery_method_def (
@@ -342,6 +338,8 @@ CREATE TABLE delivery_method_def (
     PRIMARY KEY          (do_serial),
     UNIQUE               (do_id,        do_language_id, do_set_id,    do_history_index)
 ) TYPE=innodb;
+INSERT INTO delivery_method_def (do_id, do_language_id, do_name, do_index) VALUES ('yubin',    'ja', '一般小包郵便物', 1);
+INSERT INTO delivery_method_def (do_id, do_language_id, do_name, do_index) VALUES ('takuhai',  'ja', '宅配',           2);
 
 -- 会員情報マスター
 DROP TABLE IF EXISTS shop_member;
