@@ -25,7 +25,10 @@ class admin_mainConfigsysWidgetContainer extends BaseWidgetContainer
 //	const MENUBAR_ALWAYS_VISIBLE = 'menubar_always_visible';				// 管理機能メニューバーを常時表示するかどうか
 	const MENU_ITEM_DEVELOP = 'develop';				// 「開発」メニューの識別ID
 	const SERVER_ID = 'server_id';		// サーバID
-	
+	const DEFAULT_LANG		= 'default_lang';					// デフォルト言語
+	const SITE_IN_PUBLIC = 'site_in_public';			// サイト公開状況
+	const SITE_ACCESS_EXCEPTION_IP = 'site_access_exception_ip';		// アクセス制御、例外とするIP
+		
 	/**
 	 * コンストラクタ
 	 */
@@ -65,13 +68,19 @@ class admin_mainConfigsysWidgetContainer extends BaseWidgetContainer
 		global $gConfigManager;
 		global $gEnvManager;
 		
+		$this->defaultLang		= $gEnvManager->getDefaultLanguage();
+		
 		$act = $request->trimValueOf('act');
 		$canDetailConfig = ($request->trimValueOf('item_can_detail_config') == 'on') ? 1 : 0;		// 詳細システム設定が可能かどうか
 		$regenerateSession = ($request->trimValueOf('item_regenerate_sesison') == 'on') ? 1 : 0;		// セッションIDを更新するかどうか
 		$scriptCacheInBrowser = ($request->trimValueOf('item_script_cache_in_browser') == 'on') ? 1 : 0;		// ブラウザにスクリプトのキャッシュを保持するかどうか
 		//$menubarAlwaysVisible = ($request->trimValueOf('item_menubar_always_visible') == 'on') ? 1 : 0;		// 管理機能メニューバーを常時表示するかどうか
+		$lang = $request->trimValueOf('item_lang');
 		if ($act == 'update'){		// 設定更新のとき
 			$isErr = false;
+			if (!$isErr && !empty($lang)){
+				if (!$this->db->updateSystemConfig(self::DEFAULT_LANG, $lang)) $isErr = true;
+			}
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(self::CAN_DETAIL_CONFIG, $canDetailConfig)) $isErr = true;
 			}	
@@ -94,6 +103,7 @@ class admin_mainConfigsysWidgetContainer extends BaseWidgetContainer
 			$gEnvManager->loadSystemParams();
 			
 			// 値を再取得
+			$this->defaultLang		= $gEnvManager->getDefaultLanguage();
 			$canDetailConfig	= $this->db->getSystemConfig(self::CAN_DETAIL_CONFIG);
 			$regenerateSession	= $this->db->getSystemConfig(self::REGENERATE_SESSION);
 			$scriptCacheInBrowser = $this->db->getSystemConfig(self::SCRIPT_CACHE_IN_BROWSER);
@@ -101,12 +111,50 @@ class admin_mainConfigsysWidgetContainer extends BaseWidgetContainer
 			
 			// メニュー項目の制御
 			$this->db->updateMenuVisible(self::MENU_ITEM_DEVELOP, $canDetailConfig);			// 「開発」メニュー
+		} else if ($act == 'updateip'){		// IPアドレスを更新のとき
+			$exceptIp = $request->trimValueOf('except_ip');
+
+			// 入力チェック
+			$this->checkIp($exceptIp, 'IP', true);
+			
+			// エラーなしの場合は、データを更新
+			if ($this->getMsgCount() == 0){
+				$isErr = false;
+				if (!$this->db->updateSystemConfig(self::SITE_ACCESS_EXCEPTION_IP, $exceptIp)) $isErr = true;
+				if ($isErr){
+					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
+				} else {
+					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
+				}
+			}
+		} else if ($act == 'siteopen'){		// サイト運用開始のとき
+			$this->db->updateSystemConfig(self::SITE_IN_PUBLIC, 1);
+		} else if ($act == 'siteclose'){		// サイト運用停止のとき
+			$this->db->updateSystemConfig(self::SITE_IN_PUBLIC, 0);
 		} else {		// 初期表示の場合
 			$canDetailConfig	= $this->db->getSystemConfig(self::CAN_DETAIL_CONFIG);
 			$regenerateSession	= $this->db->getSystemConfig(self::REGENERATE_SESSION);
 			$scriptCacheInBrowser = $this->db->getSystemConfig(self::SCRIPT_CACHE_IN_BROWSER);
 		//	$menubarAlwaysVisible = $this->db->getSystemConfig(self::MENUBAR_ALWAYS_VISIBLE);
 		}
+		// 言語選択メニューを作成
+		$this->db->getAllLang(array($this, 'langLoop'));
+		
+		// サイトURL
+		$this->tmpl->addVar("_widget", "site_url", $gEnvManager->getRootUrl());
+				
+		// サイト運用状況を設定
+		if ($this->db->getSystemConfig(self::SITE_IN_PUBLIC)){		// 運用中のとき
+			$this->tmpl->addVar("_widget", "site_open", '公開中');
+			$this->tmpl->addVar("_widget", "site_open_status", '0');
+			$this->tmpl->addVar("_widget", "site_open_label", '公開停止');
+		} else {
+			$this->tmpl->addVar("_widget", "site_open", '非公開');
+			$this->tmpl->addVar("_widget", "site_open_status", '1');
+			$this->tmpl->addVar("_widget", "site_open_label", '公開開始');
+		}
+		$this->tmpl->addVar("_widget", "except_ip", $this->db->getSystemConfig(self::SITE_ACCESS_EXCEPTION_IP));
+		
 		// 画面に書き戻す
 		$checked = '';
 		if ($canDetailConfig) $checked = 'checked';
@@ -190,5 +238,36 @@ class admin_mainConfigsysWidgetContainer extends BaseWidgetContainer
 		$phpinfoUrl = '?task=phpinfo&menu=off';			// メニューは非表示にする
 		$this->tmpl->addVar("_widget", "phpinfo_url", $phpinfoUrl);
 	}
+	/**
+	 * 取得した言語をテンプレートに設定する
+	 *
+	 * @param int $index			行番号(0～)
+	 * @param array $fetchedRow		フェッチ取得した行
+	 * @param object $param			未使用
+	 * @return bool					true=処理続行の場合、false=処理終了の場合
+	 */
+	function langLoop($index, $fetchedRow, $param)
+	{
+		global $gEnvManager;
+
+		$selected = '';
+		if ($fetchedRow['ln_id'] == $this->defaultLang){
+			$selected = 'selected';
+		}
+		//if ($gEnvManager->getCurrentLanguage() == 'ja'){		// 日本語表示の場合
+			$name = $this->convertToDispString($fetchedRow['ln_name']) . ' - ';
+		//} else {
+			$name .= $this->convertToDispString($fetchedRow['ln_name_en']);
+		//}
+
+		$row = array(
+			'value'    => $this->convertToDispString($fetchedRow['ln_id']),			// 言語ID
+			'name'     => $name,			// 言語名
+			'selected' => $selected														// 選択中かどうか
+		);
+		$this->tmpl->addVars('lang_list', $row);
+		$this->tmpl->parseTemplate('lang_list', 'a');
+		return true;
+	}
 }
 ?>
