@@ -1305,5 +1305,24 @@ class admin_mainDb extends BaseDb
 		$retValue = $this->selectRecords($queryStr, array($navId), $rows);
 		return $retValue;
 	}
+	/**
+	 * ナビゲーションバー項目を取得
+	 *
+	 * @param string $navId			ナビゲーションバー識別ID
+	 * @param string $parentId		親項目ID
+	 * @param array  $rows			取得レコード
+	 * @return						true=取得、false=取得せず
+	 */
+	function getNavItems($navId, $parentId, &$rows)
+	{
+		$queryStr  = 'SELECT * FROM _nav_item ';
+		$queryStr .=   'WHERE ni_nav_id = ? ';
+		$queryStr .=     'AND ni_parent_id = ? ';
+		$queryStr .=     'AND ni_visible = true ';
+		$queryStr .=   'ORDER BY ni_index';
+		
+		$retValue = $this->selectRecords($queryStr, array($navId, $parentId), $rows);
+		return $retValue;
+	}
 }
 ?>
