@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -19,6 +19,7 @@ require_once($gEnvManager->getCurrentWidgetDbPath() .	'/contactus_mainDb.php');
 class admin_contactusWidgetContainer extends BaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
+	const DEFAULT_SEND_MESSAGE = 1;		// メール送信機能を使用するかどうか(デフォルト使用)
 					
 	/**
 	 * コンストラクタ
@@ -83,7 +84,7 @@ class admin_contactusWidgetContainer extends BaseWidgetContainer
 			}
 		} else {		// 初期表示の場合
 			// デフォルト値の設定
-			$sendMessage = 0;			// メール送信機能を使用するかどうか
+			$sendMessage = self::DEFAULT_SEND_MESSAGE;			// メール送信機能を使用するかどうか
 			$emailReceiver = '';		// メール受信者
 			$companyVisible = 0;	// 会社名入力フィールドの表示
 			$addressVisible = 0;	// 住所入力フィールドの表示
