@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -51,11 +51,12 @@ class admin_default_contentWidgetContainer extends BaseWidgetContainer
 	 */
 	function _setTemplate($request, &$param)
 	{
-		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);		// 処理分岐
-		if ($task == 'createmenuitem'){
-			return 'admin_main_menuitem.tmpl.html';
-		} else {
+		global $gEnvManager;
+		
+		if ($gEnvManager->getMultiLanguage()){	// 多言語対応のとき
 			return 'admin_main.tmpl.html';
+		} else {
+			return 'admin_main_simple.tmpl.html';
 		}
 	}
 	/**
@@ -69,12 +70,7 @@ class admin_default_contentWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);		// 処理分岐
-		if ($task == 'createmenuitem'){
-			return $this->createMenuItem($request, $param);
-		} else {
-			return $this->createContentList($request, $param);
-		}
+		return $this->createContentList($request, $param);
 	}
 	/**
 	 * コンテンツ一覧画面作成
@@ -160,9 +156,9 @@ class admin_default_contentWidgetContainer extends BaseWidgetContainer
 				// エラーなしの場合は、データを登録
 				if ($this->getMsgCount() == 0){
 					if ($act == 'add'){
-						$ret = $this->db->addContentItem(0, $this->langId, $name, $html, $visible, $default, $key, $userInfo->userId, $newSerial);
+						$ret = $this->db->addContentItem(0, $this->langId, $name, ''/*説明*/, $html, $visible, $default, $key, $userInfo->userId, $newSerial);
 					} else {
-						$ret = $this->db->addContentItem($this->contentId, $this->langId, $name, $html, $visible, $default, $key, $userInfo->userId, $newSerial);
+						$ret = $this->db->addContentItem($this->contentId, $this->langId, $name, ''/*説明*/, $html, $visible, $default, $key, $userInfo->userId, $newSerial);
 					}
 					if ($ret){
 						$this->setGuidanceMsg('データを追加しました');
@@ -308,8 +304,10 @@ class admin_default_contentWidgetContainer extends BaseWidgetContainer
 			
 			//$this->db->getLangLoopByContentId(array($this, 'langLoop'), null);
 			// デフォルト言語を最初に登録
-			$this->tmpl->addVar("default_lang", "default_lang", $defaultLangName);
-			$this->tmpl->setAttribute('default_lang', 'visibility', 'visible');
+			if ($gEnvManager->getMultiLanguage()){	// 多言語対応のとき
+				$this->tmpl->addVar("default_lang", "default_lang", $defaultLangName);
+				$this->tmpl->setAttribute('default_lang', 'visibility', 'visible');
+			}
 		} else {
 			if ($this->serialNo == 0){		// 未登録データのとき
 				// データ追加ボタン表示
@@ -323,10 +321,12 @@ class admin_default_contentWidgetContainer extends BaseWidgetContainer
 				}
 				$this->tmpl->setAttribute('update_button', 'visibility', 'visible');
 			}
-			// 言語選択メニュー作成
-			if (!empty($this->contentId)){	// コンテンツが選択されているとき
-				$this->db->getAllLang(array($this, 'langLoop'));
-				$this->tmpl->setAttribute('select_lang', 'visibility', 'visible');
+			if ($gEnvManager->getMultiLanguage()){	// 多言語対応のとき
+				// 言語選択メニュー作成
+				if (!empty($this->contentId)){	// コンテンツが選択されているとき
+					$this->db->getAllLang(array($this, 'langLoop'));
+					$this->tmpl->setAttribute('select_lang', 'visibility', 'visible');
+				}
 			}
 		}
 		
@@ -354,83 +354,6 @@ class admin_default_contentWidgetContainer extends BaseWidgetContainer
 		$contIdArray = implode($this->dispContIdArray, ',');
 		$this->tmpl->addVar("_widget", "cont_ids", $contIdArray);
 	}
-	/**
-	 * メニュー項目作成画面作成
-	 *
-	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
-	 *
-	 * @param RequestManager $request		HTTPリクエスト処理クラス
-	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
-	 * @param								なし
-	 */
-	function createMenuItem($request, &$param)
-	{
-		global $gEnvManager;
-			
-		// ユーザ情報、表示言語
-		$userInfo = $gEnvManager->getCurrentUserInfo();
-		$defaultLang = $gEnvManager->getDefaultLanguage();
-		$defaultLangName = $gEnvManager->getDefaultLanguageNameByCurrentLanguage();// デフォルト言語の現在の表示名を取得
-		
-		$act = $request->trimValueOf('act');
-		$this->contentId = $request->trimValueOf('contentid');		// コンテンツID
-		$this->serialNo = $request->trimValueOf('serial');		// 選択項目のシリアル番号
-		$this->langId = $request->trimValueOf('item_lang');				// 現在メニューで選択中の言語
-		if (empty($this->langId)) $this->langId = $defaultLang;			// 言語が選択されていないときは、デフォルト言語を設定
-		$menutItemName = $request->trimValueOf('menuitemname');		// メニュー項目名
-		
-		if ($act == 'createitem'){		// メニュー項目作成
-			// 入力データエラーチェック
-			$contIdArray = explode(',', $request->trimValueOf('contidarray'));
-			if (!ValueCheck::isNumeric($contIdArray)){		// 数値かどうかのチェック
-				$this->setAppErrorMsg('数値以外が指定されています');
-			}
-			$sortValues = array();	// ソート用
-			for ($i = 0; $i < count($contIdArray); $i++){
-				// インデックス番号を取得
-				$indexNo = $request->trimValueOf('index_text' . $contIdArray[$i]);
-				if (!empty($indexNo)){		// 入力ありの場合
-					// 数値エラーチェック
-					if (ValueCheck::isNumeric($indexNo)){
-						$sortValues[$contIdArray[$i]] = intval($indexNo);
-					} else {
-						$this->setUserErrorMsg('数値以外が入力されています ID=' . $contIdArray[$i]);
-						break;
-					}
-				}
-			}
-			if (count($sortValues) <= 0) $this->setUserErrorMsg('表示順が入力されていません');
-			$this->checkInput($menutItemName, 'メニュー項目名');
-			
-			// エラーなしの場合は、データを登録
-			if ($this->getMsgCount() == 0){			
-				// 表示順にソート
-				asort($sortValues, SORT_NUMERIC);
-
-				// ソートしたコンテンツIDを取得
-				$conts = array_keys($sortValues);
-				
-				// URLの作成
-				$url = M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END . '/index.php?contentid=' . implode(',', $conts);
-				//$url = $gEnvManager->getRootUrl() . '/index.php?contentid=' . implode(',', $conts);
-
-				// メニュー項目追加
-				$ret = $this->db->addMenuItem($this->_menuId, $defaultLang, $menutItemName, $url, $userInfo->userId);
-				if ($ret){
-					$this->setGuidanceMsg('メニュー項目を追加しました');
-				} else {
-					$this->setAppErrorMsg('メニュー項目追加に失敗しました');
-				}
-			}
-		} else {
-		}
-		// コンテンツ項目リストをデフォルト言語で取得
-		$this->db->getAllContentItems(array($this, 'itemListLoop'), $defaultLang);
-		
-		// 表示中コンテンツIDを設定
-		$contIdArray = implode($this->dispContIdArray, ',');
-		$this->tmpl->addVar("_widget", "cont_ids", $contIdArray);
-	}
 	/**
 	 * 取得したデータをテンプレートに設定する
 	 *
