@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -27,15 +27,18 @@ class default_contentDb extends BaseDb
 	 */
 	function getContentItems($callback, $contentIdArray, $lang)
 	{
+		$contentType = '';
+		
 		// コンテンツIDの指定がない場合は、デフォルト値を取得
 		if ($contentIdArray == null){
 			$queryStr = 'SELECT * FROM content ';
 			$queryStr .=  'WHERE cn_visible = true ';
 			$queryStr .=    'AND cn_default = true ';
 			$queryStr .=    'AND cn_deleted = false ';		// 削除されていない
+			$queryStr .=    'AND cn_type = ? ';
 			$queryStr .=    'AND cn_language_id = ? ';
 			$queryStr .=  'ORDER BY cn_serial';
-			$this->selectLoop($queryStr, array($lang), $callback, null);
+			$this->selectLoop($queryStr, array($contentType, $lang), $callback, null);
 		} else {
 			$contentId = implode(',', $contentIdArray);
 			
@@ -49,10 +52,11 @@ class default_contentDb extends BaseDb
 			$queryStr = 'SELECT *, ' . $caseStr . ' FROM content ';
 			$queryStr .=  'WHERE cn_visible = true ';
 			$queryStr .=    'AND cn_deleted = false ';		// 削除されていない
+			$queryStr .=    'AND cn_type = ? ';
 			$queryStr .=    'AND cn_id in (' . $contentId . ') ';
 			$queryStr .=    'AND cn_language_id = ? ';
 			$queryStr .=  'ORDER BY no';
-			$this->selectLoop($queryStr, array($lang), $callback, null);
+			$this->selectLoop($queryStr, array($contentType, $lang), $callback, null);
 		}
 	}
 	/**
@@ -64,11 +68,13 @@ class default_contentDb extends BaseDb
 	 */
 	function getAllContentItems($callback, $lang)
 	{
+		$contentType = '';
 		$queryStr = 'SELECT * FROM content LEFT JOIN _login_user ON cn_create_user_id = lu_id AND lu_deleted = false ';
-		$queryStr .=  'WHERE cn_language_id = ? ';
+		$queryStr .=  'WHERE cn_type = ? ';
+		$queryStr .=    'AND cn_language_id = ? ';
 		$queryStr .=    'AND cn_deleted = false ';		// 削除されていない
 		$queryStr .=  'ORDER BY cn_id';
-		$this->selectLoop($queryStr, array($lang), $callback, null);
+		$this->selectLoop($queryStr, array($contentType, $lang), $callback, null);
 	}
 	/**
 	 * コンテンツの対応言語を取得(管理用)
@@ -78,11 +84,13 @@ class default_contentDb extends BaseDb
 	 */
 	function getLangByContentId($contentId, &$rows)
 	{
+		$contentType = '';
 		$queryStr = 'SELECT ln_id, ln_name, ln_name_en FROM content LEFT JOIN _language ON cn_language_id = ln_id ';
 		$queryStr .=  'WHERE cn_deleted = false ';	// 削除されていない
+		$queryStr .=    'AND cn_type = ? ';
 		$queryStr .=    'AND cn_id = ? ';
 		$queryStr .=  'ORDER BY cn_id, ln_priority';
-		$retValue = $this->selectRecords($queryStr, array($contentId), $rows);
+		$retValue = $this->selectRecords($queryStr, array($contentType, $contentId), $rows);
 		return $retValue;
 	}
 	/**
@@ -97,11 +105,13 @@ class default_contentDb extends BaseDb
 		// コンテンツIDがないときは終了
 		if (empty($contentId)) return;
 		
+		$contentType = '';
 		$queryStr = 'SELECT ln_id, ln_name, ln_name_en FROM content LEFT JOIN _language ON cn_language_id = ln_id ';
 		$queryStr .=  'WHERE cn_deleted = false ';	// 削除されていない
+		$queryStr .=    'AND cn_type = ? ';
 		$queryStr .=    'AND cn_id = ? ';
 		$queryStr .=  'ORDER BY cn_id, ln_priority';
-		$this->selectLoop($queryStr, array($contentId), $callback, null);
+		$this->selectLoop($queryStr, array($contentType, $contentId), $callback, null);
 	}
 	/**
 	 * コンテンツ項目をコンテンツIDで取得
@@ -113,11 +123,13 @@ class default_contentDb extends BaseDb
 	 */
 	function getContentByContentId($contentId, $langId, &$row)
 	{
+		$contentType = '';
 		$queryStr  = 'SELECT * FROM content LEFT JOIN _login_user ON cn_create_user_id = lu_id AND lu_deleted = false ';
 		$queryStr .=   'WHERE cn_deleted = false ';	// 削除されていない
+		$queryStr .=    'AND cn_type = ? ';
 		$queryStr .=   'AND cn_id = ? ';
 		$queryStr .=   'AND cn_language_id = ? ';
-		$ret = $this->selectRecord($queryStr, array($contentId, $langId), $row);
+		$ret = $this->selectRecord($queryStr, array($contentType, $contentId, $langId), $row);
 		return $ret;
 	}
 	/**
@@ -141,6 +153,7 @@ class default_contentDb extends BaseDb
 	 * @param string  $contentid	コンテンツID
 	 * @param string  $lang			言語ID
 	 * @param string  $name			コンテンツ名
+	 * @param string  $desc			説明
 	 * @param string  $html			HTML
 	 * @param bool    $visible		表示状態
 	 * @param bool    $default		デフォルトで使用するかどうか
@@ -149,15 +162,18 @@ class default_contentDb extends BaseDb
 	 * @param int     $newSerial	新規シリアル番号
 	 * @return bool					true = 成功、false = 失敗
 	 */
-	function addContentItem($contentid, $lang, $name, $html, $visible, $default, $key, $userId, &$newSerial)
-	{	
+	function addContentItem($contentid, $lang, $name, $desc, $html, $visible, $default, $key, $userId, &$newSerial)
+	{
+		$contentType = '';
+				
 		// トランザクション開始
 		$this->startTransaction();
 		
 		if ($contentid == 0){		// コンテンツIDが0のときは、コンテンツIDを新規取得
 			// コンテンツIDを決定する
 			$queryStr = 'select max(cn_id) as mid from content ';
-			$ret = $this->selectRecord($queryStr, array(), $row);
+			$queryStr .=  'WHERE cn_type = ? ';
+			$ret = $this->selectRecord($queryStr, array($contentType), $row);
 			if ($ret){
 				$contId = $row['mid'] + 1;
 			} else {
@@ -170,11 +186,11 @@ class default_contentDb extends BaseDb
 		// 前レコードの削除状態チェック
 		$historyIndex = 0;
 		$queryStr = 'SELECT * FROM content ';
-		$queryStr .=  'WHERE cn_id = ? ';
+		$queryStr .=  'WHERE cn_type = ? ';
+		$queryStr .=    'AND cn_id = ? ';
 		$queryStr .=    'AND cn_language_id = ? ';
 		$queryStr .=  'ORDER BY cn_history_index DESC ';
-		$queryStr .=    'LIMIT 1';
-		$ret = $this->selectRecord($queryStr, array($contId, $lang), $row);
+		$ret = $this->selectRecord($queryStr, array($contentType, $contId, $lang), $row);
 		if ($ret){
 			if (!$row['cn_deleted']){		// レコード存在していれば終了
 				$this->endTransaction();
@@ -185,10 +201,10 @@ class default_contentDb extends BaseDb
 		
 		// データを追加
 		$queryStr = 'INSERT INTO content ';
-		$queryStr .=  '(cn_id, cn_language_id, cn_history_index, cn_name, cn_html, cn_visible, cn_default, cn_key, cn_create_user_id, cn_create_dt) ';
+		$queryStr .=  '(cn_type, cn_id, cn_language_id, cn_history_index, cn_name, cn_description, cn_html, cn_visible, cn_default, cn_key, cn_create_user_id, cn_create_dt) ';
 		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, now())';
-		$this->execStatement($queryStr, array($contId, $lang, $historyIndex, $name, $html, $visible, $default, $key, $userId));
+		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, now())';
+		$this->execStatement($queryStr, array($contentType, $contId, $lang, $historyIndex, $name, $desc, $html, $visible, $default, $key, $userId));
 		
 		// 新規のシリアル番号取得
 		$queryStr = 'select max(cn_serial) as ns from content ';
@@ -214,7 +230,8 @@ class default_contentDb extends BaseDb
 	 * @return bool					true = 成功、false = 失敗
 	 */
 	function updateContentItem($serial, $name, $html, $visible, $default, $key, $userId, &$newSerial)
-	{	
+	{
+		$contentType = '';
 		$now = date("Y/m/d H:i:s");	// 現在日時
 				
 		// トランザクション開始
@@ -245,10 +262,10 @@ class default_contentDb extends BaseDb
 		
 		// 新規レコード追加
 		$queryStr = 'INSERT INTO content ';
-		$queryStr .=  '(cn_id, cn_language_id, cn_history_index, cn_name, cn_html, cn_visible, cn_default, cn_key, cn_create_user_id, cn_create_dt) ';
+		$queryStr .=  '(cn_type, cn_id, cn_language_id, cn_history_index, cn_name, cn_description, cn_html, cn_visible, cn_default, cn_key, cn_create_user_id, cn_create_dt) ';
 		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
-		$this->execStatement($queryStr, array($row['cn_id'], $row['cn_language_id'], $historyIndex, $name, $html, $visible, $default, $key, $userId, $now));
+		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
+		$this->execStatement($queryStr, array($row['cn_type'], $row['cn_id'], $row['cn_language_id'], $historyIndex, $name, $row['cn_description'], $html, $visible, $default, $key, $userId, $now));
 
 		// 新規のシリアル番号取得
 		$queryStr = 'select max(cn_serial) as ns from content ';
@@ -304,6 +321,8 @@ class default_contentDb extends BaseDb
 	 */
 	function delContentItemById($serial, $userId)
 	{
+		$contentType = '';
+				
 		// トランザクション開始
 		$this->startTransaction();
 		
@@ -328,21 +347,24 @@ class default_contentDb extends BaseDb
 		$queryStr .=   'SET cn_deleted = true, ';	// 削除
 		$queryStr .=     'cn_update_user_id = ?, ';
 		$queryStr .=     'cn_update_dt = now() ';
-		$queryStr .=   'WHERE cn_id = ?';
-		$this->execStatement($queryStr, array($userId, $contId));
+		$queryStr .=   'WHERE cn_type = ? ';
+		$queryStr .=     'AND cn_id = ? ';
+		$this->execStatement($queryStr, array($userId, $contentType, $contId));
 		
 		// トランザクション確定
 		$ret = $this->endTransaction();
 		return $ret;
 	}
 	/**
-	 * でコンテンツ項目をすべて削除
+	 * コンテンツ項目をすべて削除
 	 *
 	 * @param int $userId			ユーザID(データ更新者)
 	 * @return						true=成功、false=失敗
 	 */
 	function delAllContentItems($userId)
 	{
+		$contentType = '';
+			
 		// トランザクション開始
 		$this->startTransaction();
 		
@@ -351,8 +373,8 @@ class default_contentDb extends BaseDb
 		$queryStr .=   'SET cn_deleted = true, ';	// 削除
 		$queryStr .=     'cn_update_user_id = ?, ';
 		$queryStr .=     'cn_update_dt = now() ';
-		$queryStr .=   'WHERE cn_deleted = false';
-		$this->execStatement($queryStr, array($userId));
+		$queryStr .=   'WHERE cn_type = ? AND cn_deleted = false';
+		$this->execStatement($queryStr, array($userId, $contentType));
 		
 		// トランザクション確定
 		$ret = $this->endTransaction();
