@@ -21,6 +21,7 @@ class admin_default_mainmenuWidgetContainer extends BaseWidgetContainer
 	var $db;	// DB接続オブジェクト
 	var $serialNo;		// 選択中の項目のシリアル番号
 	private $_menuId = 'main_menu';				// メインメニューID
+	const CONTENT_WIDGET_ID = 'default_content';			// コンテンツ編集ウィジェット
 	
 	/**
 	 * コンストラクタ
@@ -243,6 +244,10 @@ class admin_default_mainmenuWidgetContainer extends BaseWidgetContainer
 		} else {
 			$this->tmpl->setAttribute('del_button', 'visibility', 'visible');// 「削除」ボタン
 		}
+		// コンテンツ表示ウィジェット
+		$this->tmpl->addVar('_widget', 'content_widget_id', self::CONTENT_WIDGET_ID);
+		// 管理者URL
+		$this->tmpl->addVar('_widget', 'admin_url', $gEnvManager->getDefaultAdminUrl());
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -285,6 +290,26 @@ class admin_default_mainmenuWidgetContainer extends BaseWidgetContainer
 		if ($serial == $this->serialNo){
 			$selected = 'checked';
 		}
+		
+		// リンクURLからコンテンツIDを取得
+		$linkUrl = $fetchedRow['mi_link_url'];
+		// システム配下のパスであるかチェック
+		$pos = strpos($linkUrl, M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END);
+		if ($pos === false){		// 見つからない場合
+		} else {
+			$params = explode("&", $linkUrl);
+			$count = count($params);
+			for ($i = 0; $i < $count; $i++){
+				list($key, $value) = explode('=', $params[$i]);
+				if ($key == 'contentid'){
+					$contentId = $value;
+					break;
+				}
+			}
+		}
+		// コンテンツの編集ボタンの有効状態
+		$enableContentLink = '';
+		if (empty($contentId)) $enableContentLink = 'disabled';
 		$row = array(
 			'line_color' => $lineColor,											// 行のカラー
 			'no' => $index + 1,													// 行番号
@@ -294,7 +319,9 @@ class admin_default_mainmenuWidgetContainer extends BaseWidgetContainer
 			'name' => $this->convertToDispString($fetchedRow['mi_name']),		// 名前
 			'index' => $this->convertToDispString($fetchedRow['mi_index']),		// インデックス
 			'link_type' => $linkString,											// リンクタイプ
-			'link_str' => $this->convertToDispString($fetchedRow['mi_link_url']),		// リンクURL
+			'link_str' => $this->convertToDispString($linkUrl),		// リンクURL
+			'content_id' => $contentId,											// コンテンツID
+			'enable_content' => $enableContentLink,											// コンテンツの編集ボタンの有効状態
 			'update_dt' => $this->convertToDispDateTime($fetchedRow['mi_create_dt']),	// 更新日時
 			'visible' => $visible,											// メニュー項目表示制御
 			'enable' => $enable,												// メニュー項目利用制御
