@@ -13,7 +13,6 @@
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
-//require_once($gEnvManager->getContainerPath() .			'/baseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/categoryDb.php');
 
@@ -48,7 +47,13 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 	 */
 	function _setTemplate($request, &$param)
 	{
-		return 'admin_category.tmpl.html';
+		global $gEnvManager;
+		
+		if ($gEnvManager->getMultiLanguage()){	// 多言語対応のとき
+			return 'admin_category.tmpl.html';
+		} else {
+			return 'admin_category_simple.tmpl.html';
+		}
 	}
 	/**
 	 * テンプレートにデータ埋め込む
@@ -76,9 +81,9 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 		$index	= $request->trimValueOf('item_index');		// 表示順
 		$this->categoryId = $request->trimValueOf('categoryid');	// カテゴリーID
 		if (empty($this->categoryId)) $this->categoryId = 0;
-		$this->pcategoryId = $request->trimValueOf('item_p_category');		// 親カテゴリー
-		if ($this->pcategoryId == '') $this->pcategoryId = $request->trimValueOf('pcategoryid');
-		if (empty($this->pcategoryId)) $this->pcategoryId = 0;
+		//$this->pcategoryId = $request->trimValueOf('item_p_category');		// 親カテゴリー
+		//if ($this->pcategoryId == '') $this->pcategoryId = $request->trimValueOf('pcategoryid');
+		//if (empty($this->pcategoryId)) $this->pcategoryId = 0;
 		$this->langId = $request->trimValueOf('item_lang');				// 現在メニューで選択中の言語
 		if (empty($this->langId)) $this->langId = $defaultLang;			// 言語が選択されていないときは、デフォルト言語を設定
 		$visible = ($request->trimValueOf('item_visible') == 'on') ? 1 : 0;			// 表示するかどうか
@@ -88,7 +93,7 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 				// 入力値初期化
 				$this->serialNo = 0;		// シリアル番号
 				$this->categoryId = 0;		// ID
-				$this->pcategoryId = 0;	// 親カテゴリーID
+				//$this->pcategoryId = 0;	// 親カテゴリーID
 				$this->langId = $defaultLang;
 				$name = '';		// 名前
 				$index = '';	// 表示順
@@ -102,7 +107,7 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 					$this->langId = $row['pc_language_id'];		// 言語ID
 					$name = $row['pc_name'];		// 名前
 					$index = $row['pc_sort_order'];	// 表示順
-					$this->pcategoryId = $row['pc_parent_id'];	// 親カテゴリーID
+					//$this->pcategoryId = $row['pc_parent_id'];	// 親カテゴリーID
 					$visible = $row['pc_visible'];	// 表示状態
 					$updateUser = $this->convertToDispString($row['lu_name']);	// 更新者
 					$updateDt = $this->convertToDispDateTime($row['pc_create_dt']);	// 更新日時
@@ -118,7 +123,7 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 				$this->langId = $row['pc_language_id'];		// 言語ID
 				$name = $row['pc_name'];		// 名前
 				$index = $row['pc_sort_order'];	// 表示順
-				$this->pcategoryId = $row['pc_parent_id'];	// 親カテゴリーID
+				//$this->pcategoryId = $row['pc_parent_id'];	// 親カテゴリーID
 				$visible = $row['pc_visible'];	// 表示状態
 				$updateUser = $this->convertToDispString($row['lu_name']);	// 更新者
 				$updateDt = $this->convertToDispDateTime($row['pc_create_dt']);	// 更新日時
@@ -137,9 +142,9 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 			// エラーなしの場合は、データを登録
 			if ($this->getMsgCount() == 0){
 				if ($this->serialNo == 0 && $this->categoryId == 0){		// シリアル番号が0、カテゴリIDが0のときは、新規追加モードにする
-					$ret = $this->db->addCategory(0, $this->langId, $name, $this->pcategoryId, $index, $visible, $userInfo->userId, $newSerial);
+					$ret = $this->db->addCategory(0, $this->langId, $name, 0, $index, $visible, $userInfo->userId, $newSerial);
 				} else {
-					$ret = $this->db->addCategory($this->categoryId, $this->langId, $name, $this->pcategoryId, $index, $visible, $userInfo->userId, $newSerial);
+					$ret = $this->db->addCategory($this->categoryId, $this->langId, $name, 0, $index, $visible, $userInfo->userId, $newSerial);
 				}
 				if ($ret){
 					$this->setGuidanceMsg('データを追加しました');
@@ -155,7 +160,7 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 						$this->langId = $row['pc_language_id'];		// 言語ID
 						$name = $row['pc_name'];		// 名前
 						$index = $row['pc_sort_order'];	// 表示順
-						$this->pcategoryId = $row['pc_parent_id'];	// 親カテゴリーID
+						//$this->pcategoryId = $row['pc_parent_id'];	// 親カテゴリーID
 						$visible = $row['pc_visible'];	// 表示状態
 						$updateUser = $this->convertToDispString($row['lu_name']);	// 更新者
 						$updateDt = $this->convertToDispDateTime($row['pc_create_dt']);	// 更新日時
@@ -170,14 +175,14 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 			$this->checkNumeric($index, '表示順');
 			
 			// カテゴリー階層のチェック
-//echo '-' . $this->categoryId . '-' . $this->pcategoryId;
+			/*
 			if ($this->pcategoryId != 0 && !$this->canAddCategory($this->categoryId, $this->pcategoryId)){
 				$this->setAppErrorMsg('親カテゴリーの指定に問題があります');
-			}			
+			}*/			
 			
 			// エラーなしの場合は、データを登録
 			if ($this->getMsgCount() == 0){
-				$ret = $this->db->updateCategory($this->serialNo, $name, $this->pcategoryId, $index, $visible, $userInfo->userId, $newSerial);
+				$ret = $this->db->updateCategory($this->serialNo, $name, 0, $index, $visible, $userInfo->userId, $newSerial);
 				if ($ret){
 					$this->setGuidanceMsg('データを更新しました');
 					
@@ -190,7 +195,7 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 						$this->langId = $row['pc_language_id'];		// 言語ID
 						$name = $row['pc_name'];		// 名前
 						$index = $row['pc_sort_order'];	// 表示順
-						$this->pcategoryId = $row['pc_parent_id'];	// 親カテゴリーID
+						//$this->pcategoryId = $row['pc_parent_id'];	// 親カテゴリーID
 						$visible = $row['pc_visible'];	// 表示状態
 						$updateUser = $this->convertToDispString($row['lu_name']);	// 更新者
 						$updateDt = $this->convertToDispDateTime($row['pc_create_dt']);	// 更新日時
@@ -229,20 +234,20 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 			// 入力値初期化
 			$this->serialNo = 0;		// シリアル番号
 			$this->categoryId = 0;		// ID
-			$this->pcategoryId = 0;	// 親カテゴリーID
+			//$this->pcategoryId = 0;	// 親カテゴリーID
 			$this->langId = $defaultLang;
 			$name = '';		// 名前
 			$index = '';	// 表示順
 			$visible = 1;	// 表示状態
 		}
 		// #### カテゴリーツリーを作成 ####
-		$categoryHtml =  $this->createCategoryTree($defaultLang);
-		$this->tmpl->addVar("_widget", "category_tree", $categoryHtml);
+		//$categoryHtml =  $this->createCategoryTree($defaultLang);
+		//$this->tmpl->addVar("_widget", "category_tree", $categoryHtml);
 		
 		// #### カテゴリーリストを作成 ####
-		//$this->db->getAllCategory(array($this, 'categoryListLoop'), $defaultLang);// デフォルト言語で取得
-		$categoryArray = $this->createCategoryTreeList($defaultLang);
-		if (count($categoryArray) > 0) $this->db->getCategoryByIdArray(array($this, 'categoryListLoop'), $categoryArray, $defaultLang);
+		$this->db->getAllCategory(array($this, 'categoryListLoop'), $defaultLang);// デフォルト言語で取得
+		//$categoryArray = $this->createCategoryTreeList($defaultLang);
+		//if (count($categoryArray) > 0) $this->db->getCategoryByIdArray(array($this, 'categoryListLoop'), $categoryArray, $defaultLang);
 
 		// #### 更新、新規登録部をを作成 ####
 		// 選択中のカテゴリーIDを設定
@@ -252,14 +257,18 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 			$this->tmpl->addVar("_widget", "new_selected", 'checked');// 新規追加をチェック状態にする
 			
 			// デフォルト言語を最初に登録
-			$this->tmpl->addVar("default_lang", "default_lang", $defaultLangName);
-			$this->tmpl->setAttribute('default_lang', 'visibility', 'visible');
+			if ($gEnvManager->getMultiLanguage()){	// 多言語対応のとき
+				$this->tmpl->addVar("default_lang", "default_lang", $defaultLangName);
+				$this->tmpl->setAttribute('default_lang', 'visibility', 'visible');
+			}
 		} else {
 			$this->tmpl->addVar("_widget", "id", $this->categoryId);
 			
 			// 言語選択メニューを作成
-			$this->db->getAllLang(array($this, 'langLoop'));
-			$this->tmpl->setAttribute('select_lang', 'visibility', 'visible');
+			if ($gEnvManager->getMultiLanguage()){	// 多言語対応のとき
+				$this->db->getAllLang(array($this, 'langLoop'));
+				$this->tmpl->setAttribute('select_lang', 'visibility', 'visible');
+			}
 		}
 		$this->tmpl->addVar("_widget", "name", $name);		// 名前
 		$this->tmpl->addVar("_widget", "index", $index);		// 表示順
@@ -272,12 +281,6 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 		if (!empty($updateUser)) $this->tmpl->addVar("_widget", "update_user", $updateUser);	// 更新者
 		if (!empty($updateDt)) $this->tmpl->addVar("_widget", "update_dt", $updateDt);	// 更新日時
 
-		// 親カテゴリー選択メニュー作成
-		$this->db->getAllCategory(array($this, 'categoryLoop'), $defaultLang);
-		$disabled = '';
-		if ($this->langId != $defaultLang) $disabled = 'disabled';
-		$this->tmpl->addVar("_widget", "p_category_disable", $disabled);
-
 		// ボタンの設定
 		if ($this->serialNo == 0){		// 新規追加項目を選択しているとき
 			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');// 「新規追加」ボタン
@@ -294,23 +297,9 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 		// 非表示項目の設定
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
 		$this->tmpl->addVar("_widget", "category_id", $this->categoryId);
-		$this->tmpl->addVar("_widget", "pcategory_id", $this->pcategoryId);
 		
 		// パスの設定
 		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
-		
-		/*
-		// メニューを作成
-		$menuText = '<table width="100%">';
-		$menuText .= '<tr><td><input type="button" class="button" onClick="goTask(\'category\');" value="カテゴリー登録">' . M3_NL;
-		$menuText .= '<input type="button" class="button" onClick="goTask(\'product\');" value="商品管理">' . M3_NL;
-		$menuText .= '<input type="button" class="button" onClick="goTask(\'order\');" value="受注管理">' . M3_NL;
-		$menuText .= '<input type="button" class="button" onClick="goTask(\'member\');" value="会員管理">' . M3_NL;
-		$menuText .= '<input type="button" class="button" onClick="goTask(\'shopinfo\');" value="基本設定">' . M3_NL;
-		$menuText .= '</td></tr>' . M3_NL;
-		$menuText .= '</table>' . M3_NL;
-		$menuText .= '<br>' . M3_NL;
-		$this->tmpl->addVar("_widget", "menu_items", $menuText);*/
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -384,33 +373,6 @@ class admin_ec_mainCategoryWidgetContainer extends admin_ec_mainBaseWidgetContai
 		$this->dispContIdArray[] = $fetchedRow['pc_id'];
 		return true;
 	}
-	/**
-	 * 取得した言語をテンプレートに設定する
-	 *
-	 * @param int $index			行番号(0～)
-	 * @param array $fetchedRow		フェッチ取得した行
-	 * @param object $param			未使用
-	 * @return bool					true=処理続行の場合、false=処理終了の場合
-	 */
-	function categoryLoop($index, $fetchedRow, $param)
-	{
-		global $gEnvManager;
-		
-		$selected = '';
-		if ($fetchedRow['pc_id'] == $this->pcategoryId){
-			$selected = 'selected';
-		}
-		$name = $this->convertToDispString($fetchedRow['pc_name']);
-
-		$row = array(
-			'value'    => $this->convertToDispString($fetchedRow['pc_id']),			// 言語ID
-			'name'     => $name,			// 言語名
-			'selected' => $selected														// 選択中かどうか
-		);
-		$this->tmpl->addVars('p_category_list', $row);
-		$this->tmpl->parseTemplate('p_category_list', 'a');
-		return true;
-	}
 	/**
 	 * 取得した言語をテンプレートに設定する
 	 *
