@@ -8,12 +8,11 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
-//require_once($gEnvManager->getContainerPath() .			'/baseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/ec_mainMemberDb.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/ec_mainDb.php');
@@ -375,6 +374,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 					//}
 					if ($ret){
 						$fromAddress = $this->mainDb->getConfig(self::AUTO_EMAIL_SENDER);	// 自動送信送信元
+						if (empty($fromAddress)) $fromAddress = $gEnvManager->getSiteEmail();// 送信元が取得できないときは、システムのデフォルトメールアドレスを使用
 						$toAddress = $this->convertToDispString($row['pi_email']);			// eメール(ログインアカウント)
 						$mailParam = array();
 						$mailParam['PASSWORD'] = $password;
@@ -415,8 +415,9 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 					$fp = fopen($tmpFile, "r");
 					
 					// データ読み込み
-					//while (($data = fgetByCsv($fp)) !== false){
-					while (($data = fgetByCsvWithTab($fp)) !== false){
+					$delimType = 0;
+					if ($gEnvManager->getDefaultCsvDelimCode() == "\t") $delimType = 1;		// タブ区切り
+					while (($data = fgetByCsv($fp, $delimType)) !== false){
 						if ($colCount == 0) $colCount = count($data);		// カラム数
 
 						// ヘッダ読み飛ばし
@@ -580,7 +581,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 			$memberNo = $gInstanceManager->getObject(self::EC_LIB_ID)->generateMemberNo();
 		} else if ($act == 'download'){		// CSVダウンロード
 			// ダウンロード時のデフォルトファイル名
-			$down_file = self::CSV_FILE_HEAD . date("YmdHi") . '.txt';
+			$down_file = self::CSV_FILE_HEAD . date("YmdHi") . $gEnvManager->getDefaultCsvFileSuffix();
 			
 			// ヘッダ部を作成
 			$buf = array();
@@ -598,7 +599,6 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 			$buf[] = 'パスワード';
 			$delim = $gEnvManager->getDefaultCsvDelimCode();		// CSV区切りコードを取得
 			$this->csvData[] = implode($delim, $buf) . $gEnvManager->getDefaultCsvNLCode();
-			//$this->csvData[] = implode($delim, $buf) . "\n";
 		
 			// 会員リストを取得
 			$this->db->getMemberList(0, -1/*すべて取得*/, 0, array($this, 'memberCsvListLoop'));
@@ -811,19 +811,6 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 		
 		// パスの設定
 		$this->tmpl->addVar("_widget", "script_url", $gEnvManager->getScriptsUrl());
-		
-		/*
-		// メニューを作成
-		$menuText = '<table width="100%">';
-		$menuText .= '<tr><td><input type="button" class="button" onClick="goTask(\'category\');" value="カテゴリー登録">' . M3_NL;
-		$menuText .= '<input type="button" class="button" onClick="goTask(\'product\');" value="商品管理">' . M3_NL;
-		$menuText .= '<input type="button" class="button" onClick="goTask(\'order\');" value="受注管理">' . M3_NL;
-		$menuText .= '<input type="button" class="button" onClick="goTask(\'member\');" value="会員管理">' . M3_NL;
-		$menuText .= '<input type="button" class="button" onClick="goTask(\'shopinfo\');" value="基本設定">' . M3_NL;
-		$menuText .= '</td></tr>' . M3_NL;
-		$menuText .= '</table>' . M3_NL;
-		$menuText .= '<br>' . M3_NL;
-		$this->tmpl->addVar("_widget", "menu_items", $menuText);*/
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -896,10 +883,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 		
 		// 配列を文字列に変換
 		$delim = $gEnvManager->getDefaultCsvDelimCode();		// CSV区切りコードを取得
-		if ($delim == "\t"){
-		//if ($gEnvManager->getDefaultCsvDelim() == 0){		// タブ区切りのCSVフォーマットのとき
-			//$delim = "\t";
-			
+		if ($delim == "\t"){// タブ区切りのCSVフォーマットのとき
 			$buf[] = $fetchedRow['sm_member_no'];		// 会員No
 			$buf[] = $fetchedRow['pi_email'];		// eメール(ログインアカウント)
 			$buf[] = $fetchedRow['pi_family_name'];		// 顧客名(姓)
@@ -912,9 +896,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 			$buf[] = $fetchedRow['ad_address2'];		// 住所2
 			$buf[] = $fetchedRow['ad_phone'];		// 電話番号
 			$buf[] = '';		// パスワード(ダミー)
-		} else {
-			//$delim = ",";
-			
+		} else if ($delim == ","){// カンマ区切りのCSVフォーマットのとき
 			$buf[] = $this->convertToEscapedCsv($fetchedRow['sm_member_no']);		// 会員No
 			$buf[] = $this->convertToEscapedCsv($fetchedRow['pi_email']);		// eメール(ログインアカウント)
 			$buf[] = $this->convertToEscapedCsv($fetchedRow['pi_family_name']);		// 顧客名(姓)
@@ -929,7 +911,6 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 			$buf[] = $this->convertToEscapedCsv('');		// パスワード(ダミー)
 		}
 		$this->csvData[] = implode($delim, $buf) . $gEnvManager->getDefaultCsvNLCode();
-		//$this->csvData[] = implode($delim, $buf) . "\n";
 		return true;
 	}
 	/**
