@@ -8,12 +8,11 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
-//require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
 
 class admin_ec_mainWidgetContainer extends admin_ec_mainBaseWidgetContainer
@@ -49,6 +48,8 @@ class admin_ec_mainWidgetContainer extends admin_ec_mainBaseWidgetContainer
 			case 'top';			// トップ画面
 			case 'category':	// 商品カテゴリ管理
 			case 'product':		// 商品管理
+			case 'productlist':		// 商品一覧
+			case 'productcsv':		// 商品CSVデータ
 			case 'order':		// 受注管理
 			case 'member':		// 会員管理
 			case 'shopinfo':		// ショップ情報
@@ -57,6 +58,7 @@ class admin_ec_mainWidgetContainer extends admin_ec_mainBaseWidgetContainer
 			case 'delivmethod':		// 配送方法
 			case 'init':		// 初期導入
 			case 'imageupload':		// 画像アップロード
+			case 'other':		// その他設定
 				$gLaunchManager->goSubWidget($task, true);		// 管理者機能で呼び出し
 				return false;
 			default:
