@@ -8,18 +8,19 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetDbPath() .	'/ec_mainDb.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/viewDb.php');
-require_once($gEnvManager->getCommonPath() . '/valueCheck.php');
 
 class ec_mainProductWidgetContainer extends BaseWidgetContainer
 {
 	private $db;			// DB接続オブジェクト
+	private $mainDb;			// DB接続オブジェクト
 	private $viewStyle;		// 表示スタイル
 	private $categoryId;		// カテゴリーID
 	private $productId;			// 製品ID
@@ -42,6 +43,7 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 	const VIEW_STYLE_SMALL = 'small';			// 表示スタイル(小)
 	const VIEW_STYLE_MEDIUM = 'medium';			// 表示スタイル(中)
 	const DEFAULT_LIST_COUNT = 5;			// 最大リスト表示数
+	const DISP_PRODUCT_COUNT	= 'disp_product_count';		// 商品一覧の商品表示数
 	
 	/**
 	 * コンストラクタ
@@ -55,6 +57,7 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 		
 		// DBオブジェクト作成
 		$this->db = new viewDb();
+		$this->mainDb = new ec_mainDb();
 		
 		// 価格計算用オブジェクト取得
 		$this->ecObj = $gInstanceManager->getObject(self::PRICE_OBJ_ID);
@@ -85,7 +88,7 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 		if ($act == 'inputbasketbylist'){		// 商品リストからの選択の場合
 			return 'main.tmpl.html';
 		} else {
-			if (empty($value)){		// 商品一覧のとき
+			if ($act == 'search' || empty($value)){		// 商品一覧のとき
 				return 'main.tmpl.html';
 			} else {			// 商品詳細表示
 				return 'main_detail.tmpl.html';
@@ -156,14 +159,19 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 		
 		// DBの保存設定値を取得
 		$maxListCount = self::DEFAULT_LIST_COUNT;
-		$serializedParam = $gInstanceManager->getSytemDbObject()->getWidgetParam($gEnvManager->getCurrentWidgetId());
+		$count = intval($this->mainDb->getConfig(self::DISP_PRODUCT_COUNT));						// 商品一覧の商品表示数
+		if ($count > 0) $maxListCount = $count;
+		/*$serializedParam = $gInstanceManager->getSytemDbObject()->getWidgetParam($gEnvManager->getCurrentWidgetId());
 		if (!empty($serializedParam)){
 			$dispInfo = unserialize($serializedParam);
 			$maxListCount = $dispInfo->maxListCount;		// リスト最大表示数
-		}
+		}*/
 		
 		$act = $request->trimValueOf('act');
-		if ($act == 'inputbasket' || $act == 'inputbasketbylist'){			// カートに入れる処理の場合
+		
+		if ($act == 'search'){			// 検索
+			$keyword = $request->trimValueOf('keyword');
+		} else if ($act == 'inputbasket' || $act == 'inputbasketbylist'){			// カートに入れる処理の場合
 			// クッキー読み込み、カートIDを取得
 			$cartId = $request->getCookieValue(M3_COOKIE_CART_ID);
 			if ($cartId == ''){	// カートIDが設定されていないとき
@@ -187,7 +195,7 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 				
 				// 商品情報を取得
 				$isValidItem = true;		// 現在のカートのデータが有効かどうか
-				$ret = $this->db->getProductByProductId($this->productId, $currentLang, $row, $row2, $row3, $row4);
+				$ret = $this->db->getProductByProductId($this->productId, $currentLang, $row, $row2, $row3, $row4, $row5);
 				if ($ret){
 					// 価格を取得
 					$priceArray = $this->getPrice($row2, self::STANDARD_PRICE);
@@ -247,28 +255,25 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 			$gPageManager->redirect($cartPage);
 			return;
 		}
+		// ####### 商品情報の表示 #######
 		if (empty($this->productId)){		// 商品一覧表示のとき
-			// カテゴリーリストを取得
-			if (!empty($this->categoryId)) $this->db->getCategoryList($this->categoryId, $currentLang, array($this, 'categoryListLoop'));
-	
-			// 指定カテゴリーの商品を取得
-			if (!empty($this->categoryId)){
-				// 総数を取得
-				$totalCount = $this->db->getProductCountByCategoryId($this->categoryId, $currentLang, 1);
+			// 検索からの一覧または、カテゴリー指定の一覧
+			if ($act == 'search'){
+				$totalCount = $this->db->getProductCountByKeyword($keyword, $currentLang, 1);
 				$pageCount = (int)(($totalCount -1) / $maxListCount) + 1;		// 総ページ数
-			
+				
 				// 表示するページ番号の修正
 				if ($pageNo < 1) $pageNo = 1;
 				if ($pageNo > $pageCount) $pageNo = $pageCount;
-
+				
 				// 商品リストを表示
-				$this->db->getProductByCategoryId($this->categoryId, $currentLang, 1, $maxListCount, ($pageNo -1) * $maxListCount, array($this, 'productListLoop'));
-			
+				$this->db->getProductByKeyword($keyword, $currentLang, $maxListCount, ($pageNo -1) * $maxListCount, array($this, 'productListLoop'));
+
 				// ページング用リンク作成
 				$pageLink = '';
 				if ($pageCount > 1){	// ページが2ページ以上のときリンクを作成
 					for ($i = 1; $i <= $pageCount; $i++){
-						$linkUrl = $this->currentPageUrl . '&category=' . $this->categoryId . '&page=' . $i;
+						$linkUrl = $this->currentPageUrl . '&task=product&act=search&keyword=' . urlencode($keyword) . '&page=' . $i;
 						if ($i == $pageNo){
 							$link = '&nbsp;' . $i;
 						} else {
@@ -278,17 +283,68 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 					}
 				}
 				$this->tmpl->addVar("show_productlist", "page_link", $pageLink);
-			}
+				
+				// 商品があるかチェック
+				if ($this->productExists){
+					$this->tmpl->setAttribute('show_productlist', 'visibility', 'visible');
+					$this->tmpl->addVar("show_productlist", "title", '検索結果');// タイトルを設定
+					if (empty($keyword)) $keyword = 'なし';
+					$this->tmpl->addVar("show_productlist", "detail", 'キーワード=' . $keyword . '&nbsp;&nbsp;' . $totalCount . '件');// 詳細
+				} else {
+					$this->tmpl->setAttribute('no_item_message', 'visibility', 'visible');
+					$this->tmpl->addVar("no_item_message", "title", '検索結果');// タイトルを設定
+					if (empty($keyword)) $keyword = 'なし';
+					$this->tmpl->addVar("no_item_message", "detail", 'キーワード=' . $keyword . '&nbsp;&nbsp;' . $totalCount . '件');// 詳細
+				}
+			} else {
+				// サブカテゴリーリストを取得
+				//if (!empty($this->categoryId)) $this->db->getCategoryList($this->categoryId, $currentLang, array($this, 'categoryListLoop'));
+	
+				// 指定カテゴリーの商品を取得
+				if (!empty($this->categoryId)){
+					// 総数を取得
+					$totalCount = $this->db->getProductCountByCategoryId($this->categoryId, $currentLang);
+					$pageCount = (int)(($totalCount -1) / $maxListCount) + 1;		// 総ページ数
+			
+					// 表示するページ番号の修正
+					if ($pageNo < 1) $pageNo = 1;
+					if ($pageNo > $pageCount) $pageNo = $pageCount;
+
+					// 商品リストを表示
+					$this->db->getProductByCategoryId($this->categoryId, $currentLang, $maxListCount, ($pageNo -1) * $maxListCount, array($this, 'productListLoop'));
+			
+					// ページング用リンク作成
+					$pageLink = '';
+					if ($pageCount > 1){	// ページが2ページ以上のときリンクを作成
+						for ($i = 1; $i <= $pageCount; $i++){
+							$linkUrl = $this->currentPageUrl . '&category=' . $this->categoryId . '&page=' . $i;
+							if ($i == $pageNo){
+								$link = '&nbsp;' . $i;
+							} else {
+								$link = '&nbsp;<a href="' . $linkUrl . '" >' . $i . '</a>';
+							}
+							$pageLink .= $link;
+						}
+					}
+					$this->tmpl->addVar("show_productlist", "page_link", $pageLink);
+				}
 		
-			// サブカテゴリーと商品リストの表示制御
-			// サブカテゴリーがあるかチェック
-			if ($this->subcategoryExists) $this->tmpl->setAttribute('show_subcategory', 'visibility', 'visible');
-			// 商品があるかチェック
-			if ($this->productExists) $this->tmpl->setAttribute('show_productlist', 'visibility', 'visible');
-			// 登録項目がないとき
-			if (!empty($this->categoryId) && !$this->subcategoryExists && !$this->productExists) $this->tmpl->setAttribute('no_item_message', 'visibility', 'visible');
+				// サブカテゴリーと商品リストの表示制御
+				// サブカテゴリーがあるかチェック
+				if ($this->subcategoryExists) $this->tmpl->setAttribute('show_subcategory', 'visibility', 'visible');
+				// 商品があるかチェック
+				if ($this->productExists) $this->tmpl->setAttribute('show_productlist', 'visibility', 'visible');
+				// 登録項目がないとき
+				if (!empty($this->categoryId) && !$this->subcategoryExists && !$this->productExists){
+					$this->tmpl->setAttribute('no_item_message', 'visibility', 'visible');
+					$this->tmpl->addVar("no_item_message", "detail", '項目がありません');// 詳細
+				}
+				
+				// タイトルを設定
+				$this->tmpl->addVar("show_productlist", "title", '商品一覧');
+			}
 		} else {		// 商品詳細表示のとき
-			$ret = $this->db->getProductByProductId($this->productId, $currentLang, $row, $row2, $row3, $row4);
+			$ret = $this->db->getProductByProductId($this->productId, $currentLang, $row, $row2, $row3, $row4, $row5);
 			if ($ret){
 				// 取得値を設定
 				//$this->serialNo = $row['pt_serial'];		// シリアル番号
@@ -441,18 +497,6 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 		if ($index % 2 != 0){
 			$lineColor = 'class="even"';		// 偶数行
 		}
-		// 項目選択のラジオボタンの状態
-		$id = $this->convertToDispString($fetchedRow['pt_id']);
-		$selected = '';
-		if ($id == $this->productId){
-			$selected = 'checked';
-		}
-		
-		$visible = '';
-		if ($fetchedRow['pt_visible']){	// 項目の表示
-			$visible = 'checked';
-		}
-		
 		// 商品の詳細情報を取得
 		$ret = $this->db->getProductBySerial($fetchedRow['pt_serial'], $row, $row2, $row3, $row4);
 		if ($ret){
@@ -562,21 +606,33 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 				$destImg_l .= ' />';
 			}
 		}
+		// 項目選択のラジオボタンの状態
+		$id = $this->convertToDispString($row['pt_id']);
+		$selected = '';
+		if ($id == $this->productId){
+			$selected = 'checked';
+		}
+		
+		$visible = '';
+		if ($row['pt_visible']){	// 項目の表示
+			$visible = 'checked';
+		}
+		
 		// 商品詳細リンクを作成
 		$name = '詳細';		// 名前
-		$linkUrl = $this->currentPageUrl . '&product=' . $fetchedRow['pt_id'];
+		$linkUrl = $this->currentPageUrl . '&product=' . $row['pt_id'];
 		$link = '<a href="' . $linkUrl . '" >' . $name . '</a>';
 		
 		$row = array(
 			'line_color' => $lineColor,											// 行のカラー
 			'no' => $index + 1,													// 行番号
-			'serial' => $this->convertToDispString($fetchedRow['pt_serial']),	// シリアル番号
+			'serial' => $this->convertToDispString($row['pt_serial']),	// シリアル番号
 			'id' => $id,			// ID
 			'image_s' => $destImg_s,		// 画像
 			'image_m' => $destImg_m,		// 画像
 			'image_l_url' => $imageUrl_l,		// 画像URL
-			'name' => $this->convertToDispString($fetchedRow['pt_name']),		// 名前
-			'code' => $this->convertToDispString($fetchedRow['pt_code']),		// 商品コード
+			'name' => $this->convertToDispString($row['pt_name']),		// 名前
+			'code' => $this->convertToDispString($row['pt_code']),		// 商品コード
 			'disp_total_price' => $dispPrice,				// 税込み価格
 			'description_short' => $row['pt_description_short'],				// 簡易説明
 			'product_link' => $link												// 商品詳細リンク
@@ -585,7 +641,7 @@ class ec_mainProductWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->parseTemplate('productlist', 'a');
 		
 		// 表示中のコンテンツIDを保存
-		$this->dispContIdArray[] = $fetchedRow['pt_id'];
+		$this->dispContIdArray[] = $row['pt_id'];
 		
 		$this->productExists = true;				// 商品が存在するかどうか
 		return true;
