@@ -79,10 +79,26 @@ class ec_mainDb extends BaseDb
 	{
 		$queryStr  = 'SELECT * FROM content ';
 		$queryStr .=   'WHERE cn_deleted = false ';	// 削除されていない
+		$queryStr .=   'AND cn_type = ? ';
 		$queryStr .=   'AND cn_key = ? ';
 		$queryStr .=   'AND cn_language_id = ? ';
-		$ret = $this->selectRecord($queryStr, array($key, $langId), $row);
+		$ret = $this->selectRecord($queryStr, array(''/*デフォルトコンテンツ*/, $key, $langId), $row);
 		return $ret;
 	}
+	/**
+	 * 変換キーテーブルを取得
+	 *
+	 * @param string	$key				キー文字列
+	 * @param function	$callback			コールバック関数
+	 * @return 			なし
+	 */
+	function getAllKey($key, $callback)
+	{
+		$queryStr = 'SELECT * FROM _key_value ';
+		$queryStr .=  'WHERE kv_deleted = false ';
+		$queryStr .=    'AND kv_id LIKE \'' . $key . '%\' ';
+		$queryStr .=  'ORDER BY kv_id';
+		$this->selectLoop($queryStr, array(), $callback, null);
+	}
 }
 ?>
