@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -140,6 +140,21 @@ class productDb extends BaseDb
 		$queryStr .=  'ORDER BY pt_sort_order';
 		$this->selectLoop($queryStr, array($productType, $id, $lang), $callback, null);
 	}
+	/**
+	 * すべての商品一覧を取得
+	 *
+	 * @param string	$lang				言語
+	 * @param function	$callback			コールバック関数
+	 * @return 			なし
+	 */
+	function getAllProductByLang($lang, $callback)
+	{
+		$queryStr = 'SELECT * FROM product LEFT JOIN _login_user ON pt_create_user_id = lu_id AND lu_deleted = false ';
+		$queryStr .=  'WHERE pt_deleted = false ';// 削除されていない
+		$queryStr .=    'AND pt_language_id = ? ';
+		$queryStr .=  'ORDER BY pt_sort_order';
+		$this->selectLoop($queryStr, array($lang), $callback, null);
+	}
 	/**
 	 * すべての商品一覧を取得
 	 *
@@ -162,9 +177,10 @@ class productDb extends BaseDb
 	 * @param array     $row2				商品価格
 	 * @param array     $row3				商品画像
 	 * @param array     $row4				商品ステータス
+	 * @param array     $row5				商品カテゴリー
 	 * @return bool							取得 = true, 取得なし= false
 	 */
-	function getProductBySerial($serial, &$row, &$row2, &$row3, &$row4)
+	function getProductBySerial($serial, &$row, &$row2, &$row3, &$row4, &$row5)
 	{
 		$queryStr  = 'select * from product LEFT JOIN _login_user ON pt_create_user_id = lu_id AND lu_deleted = false ';
 		$queryStr .=   'WHERE pt_serial = ? ';
@@ -189,6 +205,14 @@ class productDb extends BaseDb
 			$queryStr .=     'AND ps_id = ? ';
 			$queryStr .=     'AND ps_language_id = ? ';
 			$this->selectRecords($queryStr, array($row['pt_id'], $row['pt_language_id']), $row4);
+			
+			// 商品カテゴリー
+			$queryStr  = 'SELECT * FROM product_with_category ';
+			$queryStr .=   'WHERE pw_product_id = ? ';
+			$queryStr .=     'AND pw_language_id = ? ';
+			$queryStr .=     'AND pw_history_index = ? ';// 履歴IDは共通
+			$queryStr .=  'ORDER BY pw_index ';
+			$this->selectRecords($queryStr, array($row['pt_id'], $row['pt_language_id'], $row['pt_history_index']), $row5);
 		}
 		return $ret;
 	}
@@ -201,9 +225,10 @@ class productDb extends BaseDb
 	 * @param array     $row2				商品価格
 	 * @param array     $row3				商品画像
 	 * @param array     $row4				商品ステータス
+	 * @param array     $row5				商品カテゴリー
 	 * @return bool							取得 = true, 取得なし= false
 	 */
-	function getProductByProductId($id, $langId, &$row, &$row2, &$row3, &$row4)
+	function getProductByProductId($id, $langId, &$row, &$row2, &$row3, &$row4, &$row5)
 	{
 		$queryStr  = 'SELECT * FROM product LEFT JOIN _login_user ON pt_create_user_id = lu_id AND lu_deleted = false ';
 		$queryStr .=   'WHERE pt_deleted = false ';	// 削除されていない
@@ -230,6 +255,14 @@ class productDb extends BaseDb
 			$queryStr .=     'AND ps_id = ? ';
 			$queryStr .=     'AND ps_language_id = ? ';
 			$this->selectRecords($queryStr, array($row['pt_id'], $row['pt_language_id']), $row4);
+			
+			// 商品カテゴリー
+			$queryStr  = 'SELECT * FROM product_with_category ';
+			$queryStr .=   'WHERE pw_product_id = ? ';
+			$queryStr .=     'AND pw_language_id = ? ';
+			$queryStr .=     'AND pw_history_index = ? ';// 履歴IDは共通
+			$queryStr .=  'ORDER BY pw_index ';
+			$this->selectRecords($queryStr, array($row['pt_id'], $row['pt_language_id'], $row['pt_history_index']), $row5);
 		}
 		return $ret;
 	}
@@ -242,9 +275,10 @@ class productDb extends BaseDb
 	 * @param array     $row2				商品価格
 	 * @param array     $row3				商品画像
 	 * @param array     $row4				商品ステータス
+	 * @param array     $row5				商品カテゴリー
 	 * @return bool							取得 = true, 取得なし= false
 	 */
-	function getProductByProductCode($code, $langId, &$row, &$row2, &$row3, &$row4)
+	function getProductByProductCode($code, $langId, &$row, &$row2, &$row3, &$row4, &$row5)
 	{
 		$queryStr  = 'SELECT * FROM product LEFT JOIN _login_user ON pt_create_user_id = lu_id AND lu_deleted = false ';
 		$queryStr .=   'WHERE pt_deleted = false ';	// 削除されていない
@@ -271,6 +305,14 @@ class productDb extends BaseDb
 			$queryStr .=     'AND ps_id = ? ';
 			$queryStr .=     'AND ps_language_id = ? ';
 			$this->selectRecords($queryStr, array($row['pt_id'], $row['pt_language_id']), $row4);
+			
+			// 商品カテゴリー
+			$queryStr  = 'SELECT * FROM product_with_category ';
+			$queryStr .=   'WHERE pw_product_id = ? ';
+			$queryStr .=     'AND pw_language_id = ? ';
+			$queryStr .=     'AND pw_history_index = ? ';// 履歴IDは共通
+			$queryStr .=  'ORDER BY pw_index ';
+			$this->selectRecords($queryStr, array($row['pt_id'], $row['pt_language_id'], $row['pt_history_index']), $row5);
 		}
 		return $ret;
 	}
@@ -296,13 +338,14 @@ class productDb extends BaseDb
 	 * @param array   $prices		価格情報の配列
 	 * @param array   $images		画像の配列
 	 * @param array   $statuses		商品スタータスの配列
+	 * @param array   $categories	商品カテゴリーの配列
 	 * @param int     $userId		更新者ユーザID
 	 * @param int     $newSerial	新規シリアル番号
 	 * @return bool					true = 成功、false = 失敗
 	 */
 	function addProduct($id, $lang, $name, $code, $productType, $category, $index, $visible, $unitType, $unitQuantity, 
 								$description, $description_short, $keyword, $url, $taxType, $adminNote, 
-								$prices, $images, $statuses, $userId, &$newSerial)
+								$prices, $images, $statuses, $categories, $userId, &$newSerial)
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$startTran = false;			// この関数でトランザクションを開始したかどうか
@@ -380,6 +423,15 @@ class productDb extends BaseDb
 				return false;
 			}
 		}
+		// 商品カテゴリーの更新
+		for ($i = 0; $i < count($categories); $i++){
+			$ret = $this->updateProductCategory($pId, $lang, $historyIndex, $i, $categories[$i]);
+			if (!$ret){
+				if ($startTran) $this->endTransaction();
+				return false;
+			}
+		}
+		
 		// トランザクション確定
 		if ($startTran) $ret = $this->endTransaction();
 		return $ret;
@@ -404,12 +456,13 @@ class productDb extends BaseDb
 	 * @param array   $prices		価格情報の配列
 	 * @param array   $images		画像の配列
 	 * @param array   $statuses		商品スタータスの配列
+	 * @param array   $categories	商品カテゴリーの配列
 	 * @param int     $userId		更新者ユーザID
 	 * @param int     $newSerial	新規シリアル番号
 	 * @return bool					true = 成功、false = 失敗
 	 */
 	function updateProduct($serial, $name, $code, $category, $index, $visible, $unitType, $unitQuantity, $description, $description_short, $keyword, $url, $taxType, $adminNote,
-								$prices, $images, $statuses, $userId, &$newSerial)
+								$prices, $images, $statuses, $categories, $userId, &$newSerial)
 	{
 		$startTran = false;			// この関数でトランザクションを開始したかどうか
 		$now = date("Y/m/d H:i:s");	// 現在日時
@@ -489,14 +542,20 @@ class productDb extends BaseDb
 			$status = $statuses[$i];
 			$ret = $this->updateProductStatus($pId, $lang, $status[0], $status[1], $userId, $now);
 			if (!$ret){
-				//$this->endTransaction();
+				if ($startTran) $this->endTransaction();
+				return false;
+			}
+		}
+		// 商品カテゴリーの更新
+		for ($i = 0; $i < count($categories); $i++){
+			$ret = $this->updateProductCategory($pId, $lang, $historyIndex, $i, $categories[$i]);
+			if (!$ret){
 				if ($startTran) $this->endTransaction();
 				return false;
 			}
 		}
 		
 		// トランザクション確定
-		//$ret = $this->endTransaction();
 		if ($startTran) $ret = $this->endTransaction();
 		return $ret;
 	}
@@ -563,6 +622,15 @@ class productDb extends BaseDb
 		$queryStr .=     'AND ps_language_id = ? ';
 		$this->execStatement($queryStr, array($userId, $now, $row['pt_id'], $row['pt_language_id']));
 		
+		// 商品カテゴリーを削除
+		$queryStr  = 'UPDATE product_with_category ';
+		$queryStr .=   'SET pw_deleted = true ';	// 削除
+		$queryStr .=   'WHERE pw_deleted = false ';
+		$queryStr .=     'AND pw_product_id = ? ';
+		$queryStr .=     'AND pw_language_id = ? ';
+		$queryStr .=     'AND pw_history_index = ? ';
+		$this->execStatement($queryStr, array($row['pt_id'], $row['pt_language_id'], $row['pt_history_index']));
+		
 		// トランザクション確定
 		$ret = $this->endTransaction();
 		return $ret;
@@ -627,10 +695,35 @@ class productDb extends BaseDb
 		$queryStr .=     'AND ps_id = ? ';
 		$this->execStatement($queryStr, array($userId, $now, $row['pt_id']));
 		
+		// 商品カテゴリーを削除
+		$queryStr  = 'UPDATE product_with_category ';
+		$queryStr .=   'SET pw_deleted = true ';	// 削除
+		$queryStr .=   'WHERE pw_deleted = false ';
+		$queryStr .=     'AND pw_product_id = ? ';
+		$queryStr .=     'AND pw_language_id = ? ';
+		$queryStr .=     'AND pw_history_index = ? ';
+		$this->execStatement($queryStr, array($row['pt_id'], $row['pt_language_id'], $row['pt_history_index']));
+		
 		// トランザクション確定
 		$ret = $this->endTransaction();
 		return $ret;
 	}
+	/**
+	 * 商品カテゴリー一覧を取得
+	 *
+	 * @param string	$lang				言語
+	 * @param array		$rows				取得データ
+	 * @return bool							true=取得、false=取得せず
+	 */
+	function getAllCategory($lang, &$rows)
+	{
+		$queryStr = 'SELECT * FROM product_category LEFT JOIN _login_user ON pc_create_user_id = lu_id AND lu_deleted = false ';
+		$queryStr .=  'WHERE pc_language_id = ? ';
+		$queryStr .=    'AND pc_deleted = false ';		// 削除されていない
+		$queryStr .=  'ORDER BY pc_id';
+		$retValue = $this->selectRecords($queryStr, array($lang), $rows);
+		return $retValue;
+	}
 	/**
 	 * 商品カテゴリーをカテゴリーIDで取得
 	 *
@@ -854,7 +947,53 @@ class productDb extends BaseDb
 		$ret =$this->execStatement($queryStr, array($productId, $langId, $type, $historyIndex, $value, $userId, $now));
 		return $ret;
 	}
-	
+	/**
+	 * 商品カテゴリーの更新
+	 *
+	 * @param int        $productId		商品ID
+	 * @param string     $langId		言語ID
+	 * @param string     $historyIndex	商品情報の履歴番号
+	 * @param int        $index			インデックス番号
+	 * @param int        $categoryId	カテゴリーID
+	 * @return bool		 true = 成功、false = 失敗
+	 */
+	function updateProductCategory($productId, $langId, $historyIndex, $index, $categoryId)
+	{
+		// １つ前のレコードを削除
+		if ($historyIndex > 0){		// 履歴番号
+			$queryStr  = 'SELECT * FROM product_with_category ';
+			$queryStr .=   'WHERE pw_product_id = ? ';
+			$queryStr .=     'AND pw_language_id = ? ';
+			$queryStr .=     'AND pw_history_index = ? ';
+			$queryStr .=  'ORDER BY pw_index';
+			$ret = $this->selectRecord($queryStr, array($productId, $langId, $historyIndex -1), $row);
+			if ($ret){
+				// レコードが削除されていない場合は削除
+				if (!$row['pw_deleted']){
+					// 古いレコードを削除
+					$queryStr  = 'UPDATE product_with_category ';
+					$queryStr .=   'SET pw_deleted = true ';	// 削除
+					$queryStr .=   'WHERE pw_product_id = ? ';
+					$queryStr .=     'AND pw_language_id = ? ';
+					$queryStr .=     'AND pw_history_index = ? ';
+					$ret = $this->execStatement($queryStr, array($productId, $langId, $historyIndex -1));
+					if (!$ret) return false;
+				}
+			}
+		}
+		// 新規レコード追加
+		$queryStr = 'INSERT INTO product_with_category ';
+		$queryStr .=  '(';
+		$queryStr .=  'pw_product_id, ';
+		$queryStr .=  'pw_language_id, ';
+		$queryStr .=  'pw_history_index, ';
+		$queryStr .=  'pw_index, ';
+		$queryStr .=  'pw_category_id) ';
+		$queryStr .=  'VALUES ';
+		$queryStr .=  '(?, ?, ?, ?, ?)';
+		$ret =$this->execStatement($queryStr, array($productId, $langId, $historyIndex, $index, $categoryId));
+		return $ret;
+	}
 	/**
 	 * 商品コードが存在するかチェック
 	 *
