@@ -20,7 +20,6 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
 	private $sysDb;	// DB接続オブジェクト
-	var $categoryId;		// カテゴリーID
 	var $categoryPathArray;	// 選択中のカテゴリーの階層
 	private $paramObj;		// パラメータ保存用オブジェクト
 	private $idArray = array();		// 表示中のID
@@ -32,7 +31,7 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 	const PRODUCT_IMAGE_SMALL = 'small-product';		// 小サイズ商品画像ID
 	const PRODUCT_IMAGE_MEDIUM = 'standard-product';		// 中サイズ商品画像ID
 	const PRODUCT_IMAGE_LARGE = 'large-product';		// 大サイズ商品画像ID
-		
+	const DEFAULT_LIST_COUNT = 10;			// 最大リスト表示数		
 	/**
 	 * コンストラクタ
 	 */
@@ -111,8 +110,6 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 			
 		if (empty($this->selType)) $this->selType = $request->trimValueOf('seltype');		// 選択中の表示タイプインデックス
 		if (empty($this->selType)) $this->selType = 0;
-		$this->categoryId = $request->trimValueOf('categoryid');	// カテゴリーID
-		if (empty($this->categoryId)) $this->categoryId = 0;
 		$index = $request->trimValueOf('index');		// 処理対象項目インデックス
 		
 		$value = $request->trimValueOf('defserial');		// ページ定義のレコードシリアル番号
@@ -301,33 +298,15 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 			$gPageManager->updateParentWindow();// 親ウィンドウを更新
 		} else {		// 初期表示の場合
 			// 入力値初期化
-			$this->categoryId = 0;		// ID
 		}
-		// #### カテゴリーリストを作成 ####
-		if ($this->categoryId == 0){
-			$this->categoryPathArray = array();
-		} else {
-			$this->categoryPathArray = $this->createCategoryPath($this->categoryId);			// カテゴリーパスを作成
-		}
-		$categoryHtml =  $this->createCategoryTreeList($this->langId);
-		$this->tmpl->addVar("_widget", "category_list", $categoryHtml);
 		
 		// #### 商品リストを作成 ####
-		if ($this->categoryId == -1){
-			$this->db->getProductByCategoryId(0/*カテゴリー未設定*/, $this->langId, 1, array($this, 'productListLoop'));// 単品商品リスト取得
-		} else if ($this->categoryId != 0){
-			$this->db->getProductByCategoryId($this->categoryId, $this->langId, 1, array($this, 'productListLoop'));// 単品商品リスト取得
-		}
-
-		// 商品カテゴリー名を設定
-		$categoryName = '未選択';
-		if ($this->categoryId == -1){
-			$categoryName = '[カテゴリー外]';
-		} else if ($this->categoryId != 0){
-			$ret = $this->db->getCategoryByCategoryId($this->categoryId, $this->langId, $row);
-			if ($ret) $categoryName = $row['pc_name'];
-		}
-		$this->tmpl->addVar("_widget", "category_name", $categoryName);
+		$this->db->getAllProduct($this->langId, array($this, 'productListLoop'));
+		//if ($this->categoryId == -1){
+		//	$this->db->getProductByCategoryId(0/*カテゴリー未設定*/, $this->langId, 1, array($this, 'productListLoop'));// 単品商品リスト取得
+		//} else if ($this->categoryId != 0){
+		//	$this->db->getProductByCategoryId($this->categoryId, $this->langId, 1, array($this, 'productListLoop'));// 単品商品リスト取得
+		//}
 		
 		// 表示項目のIDを設定
 		$this->tmpl->addVar("_widget", "id_list", implode($this->idArray, ','));
@@ -344,7 +323,6 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 		// 非表示項目の設定
 		$this->tmpl->addVar("_widget", "def_serial", $defSerial);	// ページ定義のレコードシリアル番号
 		//$this->tmpl->addVar("_widget", "configid", $configId);		// 定義ID
-		$this->tmpl->addVar("_widget", "category_id", $this->categoryId);	// カテゴリーID
 		
 		// 画面にデータを埋め込む
 		$this->tmpl->addVar("_widget", "title",	$title);
@@ -362,80 +340,6 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget", "widget_url", $gEnvManager->getCurrentWidgetRootUrl());	// ウィジェットのルートディレクトリ
 		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
 	}
-	/**
-	 * ルートカテゴリーから指定したカテゴリーまでのパスを取得
-	 *
-	 * @param int $categoryId				カテゴリーID
-	 * @return array						カテゴリーパス
-	 */
-	function createCategoryPath($categoryId)
-	{
-		global $gEnvManager;
-		$pathArray = array();
-		$pCategory = $categoryId;
-		$pathArray[] = $pCategory;
-		
-		// カテゴリー最大階層まで親階層を検索
-		for ($i = 0; $i < self::MAX_HIER_LEVEL; $i++){
-			$ret = $this->db->getCategoryByCategoryId($pCategory, $this->langId, $row);
-			if ($ret){
-				$pCategory = $row['pc_parent_id'];// 親カテゴリー取得
-				$pathArray[] = $pCategory;
-				if ($pCategory == 0) break;
-			}
-		}
-		return array_reverse($pathArray);
-	}
-	/**
-	 * カテゴリーツリーリスト作成
-	 *
-	 * @param string	$langId				言語ID
-	 * @return string						カテゴリーリスト表示用HTML
-	 */
-	function createCategoryTreeList($langId)
-	{
-		$listHtml = '';
-		$this->createCategoryTreeListLoop(0, $langId, $listHtml);
-		
-		// カテゴリー外のカテゴリーを追加
-		if ($this->categoryId == -1){
-			$openStr = 'open="1"';
-			$selectStr = 'select="1"';
-		}
-		$listHtml .= '<item text="[カテゴリー外]" id="-1" ' . $openStr . ' ' . $selectStr . '>' . M3_NL;
-		$listHtml .= '</item>' . M3_NL;
-		return $listHtml;
-	}
-	/**
-	 * カテゴリーツリーリスト作成
-	 *
-	 * @param int       $parentId			親カテゴリーID
-	 * @param string	$langId				言語ID
-	 * @param array     $destArray			ツリー化したカテゴリー
-	 * @return なし	
-	 */
-	function createCategoryTreeListLoop($parentId, $langId, &$listHtml)
-	{
-		$arraySize = $this->db->getChildCategoryWithRows($parentId, $langId, $rows);
-		for ($i = 0; $i < $arraySize; $i++){
-			$id = $rows[$i]['pc_id'];
-			
-			// カテゴリーパス上の項目のときは、フォルダをオープン状態にする
-			$openStr = '';
-			$selectStr = '';	// 選択カテゴリー
-			$pathCount = count($this->categoryPathArray);	// 選択中のカテゴリーの階層
-			for ($j = 0; $j < $pathCount; $j++){
-				if ($id == $this->categoryPathArray[$j]){
-					$openStr = 'open="1"';
-					if ($j == $pathCount -1) $selectStr = 'select="1"';
-					break;
-				}
-			}
-			$listHtml .= '<item text="' . $rows[$i]['pc_name'] . '" id="' . $id . '" ' . $openStr . ' ' . $selectStr . '>' . M3_NL;
-			$this->createCategoryTreeListLoop($id, $langId, $listHtml);
-			$listHtml .= '</item>' . M3_NL;
-		}
-	}
 	/**
 	 * 取得したデータをテンプレートに設定する
 	 *
